use phf::{Map, phf_map};

// Sourced from https://html.spec.whatwg.org/entities.json at 2019-12-26T12:30:00Z.
// HTML entity reference names are case sensitive.
pub static ENTITY_REFERENCES: Map<&'static [u8], &'static [u8]> = phf_map! {
    b"AElig" => "\u{c6}".as_bytes(),
    b"AMP" => "\u{26}".as_bytes(),
    b"Aacute" => "\u{c1}".as_bytes(),
    b"Abreve" => "\u{102}".as_bytes(),
    b"Acirc" => "\u{c2}".as_bytes(),
    b"Acy" => "\u{410}".as_bytes(),
    b"Afr" => "\u{1d504}".as_bytes(),
    b"Agrave" => "\u{c0}".as_bytes(),
    b"Alpha" => "\u{391}".as_bytes(),
    b"Amacr" => "\u{100}".as_bytes(),
    b"And" => "\u{2a53}".as_bytes(),
    b"Aogon" => "\u{104}".as_bytes(),
    b"Aopf" => "\u{1d538}".as_bytes(),
    b"ApplyFunction" => "\u{2061}".as_bytes(),
    b"Aring" => "\u{c5}".as_bytes(),
    b"Ascr" => "\u{1d49c}".as_bytes(),
    b"Assign" => "\u{2254}".as_bytes(),
    b"Atilde" => "\u{c3}".as_bytes(),
    b"Auml" => "\u{c4}".as_bytes(),
    b"Backslash" => "\u{2216}".as_bytes(),
    b"Barv" => "\u{2ae7}".as_bytes(),
    b"Barwed" => "\u{2306}".as_bytes(),
    b"Bcy" => "\u{411}".as_bytes(),
    b"Because" => "\u{2235}".as_bytes(),
    b"Bernoullis" => "\u{212c}".as_bytes(),
    b"Beta" => "\u{392}".as_bytes(),
    b"Bfr" => "\u{1d505}".as_bytes(),
    b"Bopf" => "\u{1d539}".as_bytes(),
    b"Breve" => "\u{2d8}".as_bytes(),
    b"Bscr" => "\u{212c}".as_bytes(),
    b"Bumpeq" => "\u{224e}".as_bytes(),
    b"CHcy" => "\u{427}".as_bytes(),
    b"COPY" => "\u{a9}".as_bytes(),
    b"Cacute" => "\u{106}".as_bytes(),
    b"Cap" => "\u{22d2}".as_bytes(),
    b"CapitalDifferentialD" => "\u{2145}".as_bytes(),
    b"Cayleys" => "\u{212d}".as_bytes(),
    b"Ccaron" => "\u{10c}".as_bytes(),
    b"Ccedil" => "\u{c7}".as_bytes(),
    b"Ccirc" => "\u{108}".as_bytes(),
    b"Cconint" => "\u{2230}".as_bytes(),
    b"Cdot" => "\u{10a}".as_bytes(),
    b"Cedilla" => "\u{b8}".as_bytes(),
    b"CenterDot" => "\u{b7}".as_bytes(),
    b"Cfr" => "\u{212d}".as_bytes(),
    b"Chi" => "\u{3a7}".as_bytes(),
    b"CircleDot" => "\u{2299}".as_bytes(),
    b"CircleMinus" => "\u{2296}".as_bytes(),
    b"CirclePlus" => "\u{2295}".as_bytes(),
    b"CircleTimes" => "\u{2297}".as_bytes(),
    b"ClockwiseContourIntegral" => "\u{2232}".as_bytes(),
    b"CloseCurlyDoubleQuote" => "\u{201d}".as_bytes(),
    b"CloseCurlyQuote" => "\u{2019}".as_bytes(),
    b"Colon" => "\u{2237}".as_bytes(),
    b"Colone" => "\u{2a74}".as_bytes(),
    b"Congruent" => "\u{2261}".as_bytes(),
    b"Conint" => "\u{222f}".as_bytes(),
    b"ContourIntegral" => "\u{222e}".as_bytes(),
    b"Copf" => "\u{2102}".as_bytes(),
    b"Coproduct" => "\u{2210}".as_bytes(),
    b"CounterClockwiseContourIntegral" => "\u{2233}".as_bytes(),
    b"Cross" => "\u{2a2f}".as_bytes(),
    b"Cscr" => "\u{1d49e}".as_bytes(),
    b"Cup" => "\u{22d3}".as_bytes(),
    b"CupCap" => "\u{224d}".as_bytes(),
    b"DD" => "\u{2145}".as_bytes(),
    b"DDotrahd" => "\u{2911}".as_bytes(),
    b"DJcy" => "\u{402}".as_bytes(),
    b"DScy" => "\u{405}".as_bytes(),
    b"DZcy" => "\u{40f}".as_bytes(),
    b"Dagger" => "\u{2021}".as_bytes(),
    b"Darr" => "\u{21a1}".as_bytes(),
    b"Dashv" => "\u{2ae4}".as_bytes(),
    b"Dcaron" => "\u{10e}".as_bytes(),
    b"Dcy" => "\u{414}".as_bytes(),
    b"Del" => "\u{2207}".as_bytes(),
    b"Delta" => "\u{394}".as_bytes(),
    b"Dfr" => "\u{1d507}".as_bytes(),
    b"DiacriticalAcute" => "\u{b4}".as_bytes(),
    b"DiacriticalDot" => "\u{2d9}".as_bytes(),
    b"DiacriticalDoubleAcute" => "\u{2dd}".as_bytes(),
    b"DiacriticalGrave" => "\u{60}".as_bytes(),
    b"DiacriticalTilde" => "\u{2dc}".as_bytes(),
    b"Diamond" => "\u{22c4}".as_bytes(),
    b"DifferentialD" => "\u{2146}".as_bytes(),
    b"Dopf" => "\u{1d53b}".as_bytes(),
    b"Dot" => "\u{a8}".as_bytes(),
    b"DotDot" => "\u{20dc}".as_bytes(),
    b"DotEqual" => "\u{2250}".as_bytes(),
    b"DoubleContourIntegral" => "\u{222f}".as_bytes(),
    b"DoubleDot" => "\u{a8}".as_bytes(),
    b"DoubleDownArrow" => "\u{21d3}".as_bytes(),
    b"DoubleLeftArrow" => "\u{21d0}".as_bytes(),
    b"DoubleLeftRightArrow" => "\u{21d4}".as_bytes(),
    b"DoubleLeftTee" => "\u{2ae4}".as_bytes(),
    b"DoubleLongLeftArrow" => "\u{27f8}".as_bytes(),
    b"DoubleLongLeftRightArrow" => "\u{27fa}".as_bytes(),
    b"DoubleLongRightArrow" => "\u{27f9}".as_bytes(),
    b"DoubleRightArrow" => "\u{21d2}".as_bytes(),
    b"DoubleRightTee" => "\u{22a8}".as_bytes(),
    b"DoubleUpArrow" => "\u{21d1}".as_bytes(),
    b"DoubleUpDownArrow" => "\u{21d5}".as_bytes(),
    b"DoubleVerticalBar" => "\u{2225}".as_bytes(),
    b"DownArrow" => "\u{2193}".as_bytes(),
    b"DownArrowBar" => "\u{2913}".as_bytes(),
    b"DownArrowUpArrow" => "\u{21f5}".as_bytes(),
    b"DownBreve" => "\u{311}".as_bytes(),
    b"DownLeftRightVector" => "\u{2950}".as_bytes(),
    b"DownLeftTeeVector" => "\u{295e}".as_bytes(),
    b"DownLeftVector" => "\u{21bd}".as_bytes(),
    b"DownLeftVectorBar" => "\u{2956}".as_bytes(),
    b"DownRightTeeVector" => "\u{295f}".as_bytes(),
    b"DownRightVector" => "\u{21c1}".as_bytes(),
    b"DownRightVectorBar" => "\u{2957}".as_bytes(),
    b"DownTee" => "\u{22a4}".as_bytes(),
    b"DownTeeArrow" => "\u{21a7}".as_bytes(),
    b"Downarrow" => "\u{21d3}".as_bytes(),
    b"Dscr" => "\u{1d49f}".as_bytes(),
    b"Dstrok" => "\u{110}".as_bytes(),
    b"ENG" => "\u{14a}".as_bytes(),
    b"ETH" => "\u{d0}".as_bytes(),
    b"Eacute" => "\u{c9}".as_bytes(),
    b"Ecaron" => "\u{11a}".as_bytes(),
    b"Ecirc" => "\u{ca}".as_bytes(),
    b"Ecy" => "\u{42d}".as_bytes(),
    b"Edot" => "\u{116}".as_bytes(),
    b"Efr" => "\u{1d508}".as_bytes(),
    b"Egrave" => "\u{c8}".as_bytes(),
    b"Element" => "\u{2208}".as_bytes(),
    b"Emacr" => "\u{112}".as_bytes(),
    b"EmptySmallSquare" => "\u{25fb}".as_bytes(),
    b"EmptyVerySmallSquare" => "\u{25ab}".as_bytes(),
    b"Eogon" => "\u{118}".as_bytes(),
    b"Eopf" => "\u{1d53c}".as_bytes(),
    b"Epsilon" => "\u{395}".as_bytes(),
    b"Equal" => "\u{2a75}".as_bytes(),
    b"EqualTilde" => "\u{2242}".as_bytes(),
    b"Equilibrium" => "\u{21cc}".as_bytes(),
    b"Escr" => "\u{2130}".as_bytes(),
    b"Esim" => "\u{2a73}".as_bytes(),
    b"Eta" => "\u{397}".as_bytes(),
    b"Euml" => "\u{cb}".as_bytes(),
    b"Exists" => "\u{2203}".as_bytes(),
    b"ExponentialE" => "\u{2147}".as_bytes(),
    b"Fcy" => "\u{424}".as_bytes(),
    b"Ffr" => "\u{1d509}".as_bytes(),
    b"FilledSmallSquare" => "\u{25fc}".as_bytes(),
    b"FilledVerySmallSquare" => "\u{25aa}".as_bytes(),
    b"Fopf" => "\u{1d53d}".as_bytes(),
    b"ForAll" => "\u{2200}".as_bytes(),
    b"Fouriertrf" => "\u{2131}".as_bytes(),
    b"Fscr" => "\u{2131}".as_bytes(),
    b"GJcy" => "\u{403}".as_bytes(),
    b"GT" => "\u{3e}".as_bytes(),
    b"Gamma" => "\u{393}".as_bytes(),
    b"Gammad" => "\u{3dc}".as_bytes(),
    b"Gbreve" => "\u{11e}".as_bytes(),
    b"Gcedil" => "\u{122}".as_bytes(),
    b"Gcirc" => "\u{11c}".as_bytes(),
    b"Gcy" => "\u{413}".as_bytes(),
    b"Gdot" => "\u{120}".as_bytes(),
    b"Gfr" => "\u{1d50a}".as_bytes(),
    b"Gg" => "\u{22d9}".as_bytes(),
    b"Gopf" => "\u{1d53e}".as_bytes(),
    b"GreaterEqual" => "\u{2265}".as_bytes(),
    b"GreaterEqualLess" => "\u{22db}".as_bytes(),
    b"GreaterFullEqual" => "\u{2267}".as_bytes(),
    b"GreaterGreater" => "\u{2aa2}".as_bytes(),
    b"GreaterLess" => "\u{2277}".as_bytes(),
    b"GreaterSlantEqual" => "\u{2a7e}".as_bytes(),
    b"GreaterTilde" => "\u{2273}".as_bytes(),
    b"Gscr" => "\u{1d4a2}".as_bytes(),
    b"Gt" => "\u{226b}".as_bytes(),
    b"HARDcy" => "\u{42a}".as_bytes(),
    b"Hacek" => "\u{2c7}".as_bytes(),
    b"Hat" => "\u{5e}".as_bytes(),
    b"Hcirc" => "\u{124}".as_bytes(),
    b"Hfr" => "\u{210c}".as_bytes(),
    b"HilbertSpace" => "\u{210b}".as_bytes(),
    b"Hopf" => "\u{210d}".as_bytes(),
    b"HorizontalLine" => "\u{2500}".as_bytes(),
    b"Hscr" => "\u{210b}".as_bytes(),
    b"Hstrok" => "\u{126}".as_bytes(),
    b"HumpDownHump" => "\u{224e}".as_bytes(),
    b"HumpEqual" => "\u{224f}".as_bytes(),
    b"IEcy" => "\u{415}".as_bytes(),
    b"IJlig" => "\u{132}".as_bytes(),
    b"IOcy" => "\u{401}".as_bytes(),
    b"Iacute" => "\u{cd}".as_bytes(),
    b"Icirc" => "\u{ce}".as_bytes(),
    b"Icy" => "\u{418}".as_bytes(),
    b"Idot" => "\u{130}".as_bytes(),
    b"Ifr" => "\u{2111}".as_bytes(),
    b"Igrave" => "\u{cc}".as_bytes(),
    b"Im" => "\u{2111}".as_bytes(),
    b"Imacr" => "\u{12a}".as_bytes(),
    b"ImaginaryI" => "\u{2148}".as_bytes(),
    b"Implies" => "\u{21d2}".as_bytes(),
    b"Int" => "\u{222c}".as_bytes(),
    b"Integral" => "\u{222b}".as_bytes(),
    b"Intersection" => "\u{22c2}".as_bytes(),
    b"InvisibleComma" => "\u{2063}".as_bytes(),
    b"InvisibleTimes" => "\u{2062}".as_bytes(),
    b"Iogon" => "\u{12e}".as_bytes(),
    b"Iopf" => "\u{1d540}".as_bytes(),
    b"Iota" => "\u{399}".as_bytes(),
    b"Iscr" => "\u{2110}".as_bytes(),
    b"Itilde" => "\u{128}".as_bytes(),
    b"Iukcy" => "\u{406}".as_bytes(),
    b"Iuml" => "\u{cf}".as_bytes(),
    b"Jcirc" => "\u{134}".as_bytes(),
    b"Jcy" => "\u{419}".as_bytes(),
    b"Jfr" => "\u{1d50d}".as_bytes(),
    b"Jopf" => "\u{1d541}".as_bytes(),
    b"Jscr" => "\u{1d4a5}".as_bytes(),
    b"Jsercy" => "\u{408}".as_bytes(),
    b"Jukcy" => "\u{404}".as_bytes(),
    b"KHcy" => "\u{425}".as_bytes(),
    b"KJcy" => "\u{40c}".as_bytes(),
    b"Kappa" => "\u{39a}".as_bytes(),
    b"Kcedil" => "\u{136}".as_bytes(),
    b"Kcy" => "\u{41a}".as_bytes(),
    b"Kfr" => "\u{1d50e}".as_bytes(),
    b"Kopf" => "\u{1d542}".as_bytes(),
    b"Kscr" => "\u{1d4a6}".as_bytes(),
    b"LJcy" => "\u{409}".as_bytes(),
    b"LT" => "\u{3c}".as_bytes(),
    b"Lacute" => "\u{139}".as_bytes(),
    b"Lambda" => "\u{39b}".as_bytes(),
    b"Lang" => "\u{27ea}".as_bytes(),
    b"Laplacetrf" => "\u{2112}".as_bytes(),
    b"Larr" => "\u{219e}".as_bytes(),
    b"Lcaron" => "\u{13d}".as_bytes(),
    b"Lcedil" => "\u{13b}".as_bytes(),
    b"Lcy" => "\u{41b}".as_bytes(),
    b"LeftAngleBracket" => "\u{27e8}".as_bytes(),
    b"LeftArrow" => "\u{2190}".as_bytes(),
    b"LeftArrowBar" => "\u{21e4}".as_bytes(),
    b"LeftArrowRightArrow" => "\u{21c6}".as_bytes(),
    b"LeftCeiling" => "\u{2308}".as_bytes(),
    b"LeftDoubleBracket" => "\u{27e6}".as_bytes(),
    b"LeftDownTeeVector" => "\u{2961}".as_bytes(),
    b"LeftDownVector" => "\u{21c3}".as_bytes(),
    b"LeftDownVectorBar" => "\u{2959}".as_bytes(),
    b"LeftFloor" => "\u{230a}".as_bytes(),
    b"LeftRightArrow" => "\u{2194}".as_bytes(),
    b"LeftRightVector" => "\u{294e}".as_bytes(),
    b"LeftTee" => "\u{22a3}".as_bytes(),
    b"LeftTeeArrow" => "\u{21a4}".as_bytes(),
    b"LeftTeeVector" => "\u{295a}".as_bytes(),
    b"LeftTriangle" => "\u{22b2}".as_bytes(),
    b"LeftTriangleBar" => "\u{29cf}".as_bytes(),
    b"LeftTriangleEqual" => "\u{22b4}".as_bytes(),
    b"LeftUpDownVector" => "\u{2951}".as_bytes(),
    b"LeftUpTeeVector" => "\u{2960}".as_bytes(),
    b"LeftUpVector" => "\u{21bf}".as_bytes(),
    b"LeftUpVectorBar" => "\u{2958}".as_bytes(),
    b"LeftVector" => "\u{21bc}".as_bytes(),
    b"LeftVectorBar" => "\u{2952}".as_bytes(),
    b"Leftarrow" => "\u{21d0}".as_bytes(),
    b"Leftrightarrow" => "\u{21d4}".as_bytes(),
    b"LessEqualGreater" => "\u{22da}".as_bytes(),
    b"LessFullEqual" => "\u{2266}".as_bytes(),
    b"LessGreater" => "\u{2276}".as_bytes(),
    b"LessLess" => "\u{2aa1}".as_bytes(),
    b"LessSlantEqual" => "\u{2a7d}".as_bytes(),
    b"LessTilde" => "\u{2272}".as_bytes(),
    b"Lfr" => "\u{1d50f}".as_bytes(),
    b"Ll" => "\u{22d8}".as_bytes(),
    b"Lleftarrow" => "\u{21da}".as_bytes(),
    b"Lmidot" => "\u{13f}".as_bytes(),
    b"LongLeftArrow" => "\u{27f5}".as_bytes(),
    b"LongLeftRightArrow" => "\u{27f7}".as_bytes(),
    b"LongRightArrow" => "\u{27f6}".as_bytes(),
    b"Longleftarrow" => "\u{27f8}".as_bytes(),
    b"Longleftrightarrow" => "\u{27fa}".as_bytes(),
    b"Longrightarrow" => "\u{27f9}".as_bytes(),
    b"Lopf" => "\u{1d543}".as_bytes(),
    b"LowerLeftArrow" => "\u{2199}".as_bytes(),
    b"LowerRightArrow" => "\u{2198}".as_bytes(),
    b"Lscr" => "\u{2112}".as_bytes(),
    b"Lsh" => "\u{21b0}".as_bytes(),
    b"Lstrok" => "\u{141}".as_bytes(),
    b"Lt" => "\u{226a}".as_bytes(),
    b"Map" => "\u{2905}".as_bytes(),
    b"Mcy" => "\u{41c}".as_bytes(),
    b"MediumSpace" => "\u{205f}".as_bytes(),
    b"Mellintrf" => "\u{2133}".as_bytes(),
    b"Mfr" => "\u{1d510}".as_bytes(),
    b"MinusPlus" => "\u{2213}".as_bytes(),
    b"Mopf" => "\u{1d544}".as_bytes(),
    b"Mscr" => "\u{2133}".as_bytes(),
    b"Mu" => "\u{39c}".as_bytes(),
    b"NJcy" => "\u{40a}".as_bytes(),
    b"Nacute" => "\u{143}".as_bytes(),
    b"Ncaron" => "\u{147}".as_bytes(),
    b"Ncedil" => "\u{145}".as_bytes(),
    b"Ncy" => "\u{41d}".as_bytes(),
    b"NegativeMediumSpace" => "\u{200b}".as_bytes(),
    b"NegativeThickSpace" => "\u{200b}".as_bytes(),
    b"NegativeThinSpace" => "\u{200b}".as_bytes(),
    b"NegativeVeryThinSpace" => "\u{200b}".as_bytes(),
    b"NestedGreaterGreater" => "\u{226b}".as_bytes(),
    b"NestedLessLess" => "\u{226a}".as_bytes(),
    b"NewLine" => "\u{a}".as_bytes(),
    b"Nfr" => "\u{1d511}".as_bytes(),
    b"NoBreak" => "\u{2060}".as_bytes(),
    b"NonBreakingSpace" => "\u{a0}".as_bytes(),
    b"Nopf" => "\u{2115}".as_bytes(),
    b"Not" => "\u{2aec}".as_bytes(),
    b"NotCongruent" => "\u{2262}".as_bytes(),
    b"NotCupCap" => "\u{226d}".as_bytes(),
    b"NotDoubleVerticalBar" => "\u{2226}".as_bytes(),
    b"NotElement" => "\u{2209}".as_bytes(),
    b"NotEqual" => "\u{2260}".as_bytes(),
    b"NotEqualTilde" => "\u{2242},\u{338}".as_bytes(),
    b"NotExists" => "\u{2204}".as_bytes(),
    b"NotGreater" => "\u{226f}".as_bytes(),
    b"NotGreaterEqual" => "\u{2271}".as_bytes(),
    b"NotGreaterFullEqual" => "\u{2267},\u{338}".as_bytes(),
    b"NotGreaterGreater" => "\u{226b},\u{338}".as_bytes(),
    b"NotGreaterLess" => "\u{2279}".as_bytes(),
    b"NotGreaterSlantEqual" => "\u{2a7e},\u{338}".as_bytes(),
    b"NotGreaterTilde" => "\u{2275}".as_bytes(),
    b"NotHumpDownHump" => "\u{224e},\u{338}".as_bytes(),
    b"NotHumpEqual" => "\u{224f},\u{338}".as_bytes(),
    b"NotLeftTriangle" => "\u{22ea}".as_bytes(),
    b"NotLeftTriangleBar" => "\u{29cf},\u{338}".as_bytes(),
    b"NotLeftTriangleEqual" => "\u{22ec}".as_bytes(),
    b"NotLess" => "\u{226e}".as_bytes(),
    b"NotLessEqual" => "\u{2270}".as_bytes(),
    b"NotLessGreater" => "\u{2278}".as_bytes(),
    b"NotLessLess" => "\u{226a},\u{338}".as_bytes(),
    b"NotLessSlantEqual" => "\u{2a7d},\u{338}".as_bytes(),
    b"NotLessTilde" => "\u{2274}".as_bytes(),
    b"NotNestedGreaterGreater" => "\u{2aa2},\u{338}".as_bytes(),
    b"NotNestedLessLess" => "\u{2aa1},\u{338}".as_bytes(),
    b"NotPrecedes" => "\u{2280}".as_bytes(),
    b"NotPrecedesEqual" => "\u{2aaf},\u{338}".as_bytes(),
    b"NotPrecedesSlantEqual" => "\u{22e0}".as_bytes(),
    b"NotReverseElement" => "\u{220c}".as_bytes(),
    b"NotRightTriangle" => "\u{22eb}".as_bytes(),
    b"NotRightTriangleBar" => "\u{29d0},\u{338}".as_bytes(),
    b"NotRightTriangleEqual" => "\u{22ed}".as_bytes(),
    b"NotSquareSubset" => "\u{228f},\u{338}".as_bytes(),
    b"NotSquareSubsetEqual" => "\u{22e2}".as_bytes(),
    b"NotSquareSuperset" => "\u{2290},\u{338}".as_bytes(),
    b"NotSquareSupersetEqual" => "\u{22e3}".as_bytes(),
    b"NotSubset" => "\u{2282},\u{20d2}".as_bytes(),
    b"NotSubsetEqual" => "\u{2288}".as_bytes(),
    b"NotSucceeds" => "\u{2281}".as_bytes(),
    b"NotSucceedsEqual" => "\u{2ab0},\u{338}".as_bytes(),
    b"NotSucceedsSlantEqual" => "\u{22e1}".as_bytes(),
    b"NotSucceedsTilde" => "\u{227f},\u{338}".as_bytes(),
    b"NotSuperset" => "\u{2283},\u{20d2}".as_bytes(),
    b"NotSupersetEqual" => "\u{2289}".as_bytes(),
    b"NotTilde" => "\u{2241}".as_bytes(),
    b"NotTildeEqual" => "\u{2244}".as_bytes(),
    b"NotTildeFullEqual" => "\u{2247}".as_bytes(),
    b"NotTildeTilde" => "\u{2249}".as_bytes(),
    b"NotVerticalBar" => "\u{2224}".as_bytes(),
    b"Nscr" => "\u{1d4a9}".as_bytes(),
    b"Ntilde" => "\u{d1}".as_bytes(),
    b"Nu" => "\u{39d}".as_bytes(),
    b"OElig" => "\u{152}".as_bytes(),
    b"Oacute" => "\u{d3}".as_bytes(),
    b"Ocirc" => "\u{d4}".as_bytes(),
    b"Ocy" => "\u{41e}".as_bytes(),
    b"Odblac" => "\u{150}".as_bytes(),
    b"Ofr" => "\u{1d512}".as_bytes(),
    b"Ograve" => "\u{d2}".as_bytes(),
    b"Omacr" => "\u{14c}".as_bytes(),
    b"Omega" => "\u{3a9}".as_bytes(),
    b"Omicron" => "\u{39f}".as_bytes(),
    b"Oopf" => "\u{1d546}".as_bytes(),
    b"OpenCurlyDoubleQuote" => "\u{201c}".as_bytes(),
    b"OpenCurlyQuote" => "\u{2018}".as_bytes(),
    b"Or" => "\u{2a54}".as_bytes(),
    b"Oscr" => "\u{1d4aa}".as_bytes(),
    b"Oslash" => "\u{d8}".as_bytes(),
    b"Otilde" => "\u{d5}".as_bytes(),
    b"Otimes" => "\u{2a37}".as_bytes(),
    b"Ouml" => "\u{d6}".as_bytes(),
    b"OverBar" => "\u{203e}".as_bytes(),
    b"OverBrace" => "\u{23de}".as_bytes(),
    b"OverBracket" => "\u{23b4}".as_bytes(),
    b"OverParenthesis" => "\u{23dc}".as_bytes(),
    b"PartialD" => "\u{2202}".as_bytes(),
    b"Pcy" => "\u{41f}".as_bytes(),
    b"Pfr" => "\u{1d513}".as_bytes(),
    b"Phi" => "\u{3a6}".as_bytes(),
    b"Pi" => "\u{3a0}".as_bytes(),
    b"PlusMinus" => "\u{b1}".as_bytes(),
    b"Poincareplane" => "\u{210c}".as_bytes(),
    b"Popf" => "\u{2119}".as_bytes(),
    b"Pr" => "\u{2abb}".as_bytes(),
    b"Precedes" => "\u{227a}".as_bytes(),
    b"PrecedesEqual" => "\u{2aaf}".as_bytes(),
    b"PrecedesSlantEqual" => "\u{227c}".as_bytes(),
    b"PrecedesTilde" => "\u{227e}".as_bytes(),
    b"Prime" => "\u{2033}".as_bytes(),
    b"Product" => "\u{220f}".as_bytes(),
    b"Proportion" => "\u{2237}".as_bytes(),
    b"Proportional" => "\u{221d}".as_bytes(),
    b"Pscr" => "\u{1d4ab}".as_bytes(),
    b"Psi" => "\u{3a8}".as_bytes(),
    b"QUOT" => "\u{22}".as_bytes(),
    b"Qfr" => "\u{1d514}".as_bytes(),
    b"Qopf" => "\u{211a}".as_bytes(),
    b"Qscr" => "\u{1d4ac}".as_bytes(),
    b"RBarr" => "\u{2910}".as_bytes(),
    b"REG" => "\u{ae}".as_bytes(),
    b"Racute" => "\u{154}".as_bytes(),
    b"Rang" => "\u{27eb}".as_bytes(),
    b"Rarr" => "\u{21a0}".as_bytes(),
    b"Rarrtl" => "\u{2916}".as_bytes(),
    b"Rcaron" => "\u{158}".as_bytes(),
    b"Rcedil" => "\u{156}".as_bytes(),
    b"Rcy" => "\u{420}".as_bytes(),
    b"Re" => "\u{211c}".as_bytes(),
    b"ReverseElement" => "\u{220b}".as_bytes(),
    b"ReverseEquilibrium" => "\u{21cb}".as_bytes(),
    b"ReverseUpEquilibrium" => "\u{296f}".as_bytes(),
    b"Rfr" => "\u{211c}".as_bytes(),
    b"Rho" => "\u{3a1}".as_bytes(),
    b"RightAngleBracket" => "\u{27e9}".as_bytes(),
    b"RightArrow" => "\u{2192}".as_bytes(),
    b"RightArrowBar" => "\u{21e5}".as_bytes(),
    b"RightArrowLeftArrow" => "\u{21c4}".as_bytes(),
    b"RightCeiling" => "\u{2309}".as_bytes(),
    b"RightDoubleBracket" => "\u{27e7}".as_bytes(),
    b"RightDownTeeVector" => "\u{295d}".as_bytes(),
    b"RightDownVector" => "\u{21c2}".as_bytes(),
    b"RightDownVectorBar" => "\u{2955}".as_bytes(),
    b"RightFloor" => "\u{230b}".as_bytes(),
    b"RightTee" => "\u{22a2}".as_bytes(),
    b"RightTeeArrow" => "\u{21a6}".as_bytes(),
    b"RightTeeVector" => "\u{295b}".as_bytes(),
    b"RightTriangle" => "\u{22b3}".as_bytes(),
    b"RightTriangleBar" => "\u{29d0}".as_bytes(),
    b"RightTriangleEqual" => "\u{22b5}".as_bytes(),
    b"RightUpDownVector" => "\u{294f}".as_bytes(),
    b"RightUpTeeVector" => "\u{295c}".as_bytes(),
    b"RightUpVector" => "\u{21be}".as_bytes(),
    b"RightUpVectorBar" => "\u{2954}".as_bytes(),
    b"RightVector" => "\u{21c0}".as_bytes(),
    b"RightVectorBar" => "\u{2953}".as_bytes(),
    b"Rightarrow" => "\u{21d2}".as_bytes(),
    b"Ropf" => "\u{211d}".as_bytes(),
    b"RoundImplies" => "\u{2970}".as_bytes(),
    b"Rrightarrow" => "\u{21db}".as_bytes(),
    b"Rscr" => "\u{211b}".as_bytes(),
    b"Rsh" => "\u{21b1}".as_bytes(),
    b"RuleDelayed" => "\u{29f4}".as_bytes(),
    b"SHCHcy" => "\u{429}".as_bytes(),
    b"SHcy" => "\u{428}".as_bytes(),
    b"SOFTcy" => "\u{42c}".as_bytes(),
    b"Sacute" => "\u{15a}".as_bytes(),
    b"Sc" => "\u{2abc}".as_bytes(),
    b"Scaron" => "\u{160}".as_bytes(),
    b"Scedil" => "\u{15e}".as_bytes(),
    b"Scirc" => "\u{15c}".as_bytes(),
    b"Scy" => "\u{421}".as_bytes(),
    b"Sfr" => "\u{1d516}".as_bytes(),
    b"ShortDownArrow" => "\u{2193}".as_bytes(),
    b"ShortLeftArrow" => "\u{2190}".as_bytes(),
    b"ShortRightArrow" => "\u{2192}".as_bytes(),
    b"ShortUpArrow" => "\u{2191}".as_bytes(),
    b"Sigma" => "\u{3a3}".as_bytes(),
    b"SmallCircle" => "\u{2218}".as_bytes(),
    b"Sopf" => "\u{1d54a}".as_bytes(),
    b"Sqrt" => "\u{221a}".as_bytes(),
    b"Square" => "\u{25a1}".as_bytes(),
    b"SquareIntersection" => "\u{2293}".as_bytes(),
    b"SquareSubset" => "\u{228f}".as_bytes(),
    b"SquareSubsetEqual" => "\u{2291}".as_bytes(),
    b"SquareSuperset" => "\u{2290}".as_bytes(),
    b"SquareSupersetEqual" => "\u{2292}".as_bytes(),
    b"SquareUnion" => "\u{2294}".as_bytes(),
    b"Sscr" => "\u{1d4ae}".as_bytes(),
    b"Star" => "\u{22c6}".as_bytes(),
    b"Sub" => "\u{22d0}".as_bytes(),
    b"Subset" => "\u{22d0}".as_bytes(),
    b"SubsetEqual" => "\u{2286}".as_bytes(),
    b"Succeeds" => "\u{227b}".as_bytes(),
    b"SucceedsEqual" => "\u{2ab0}".as_bytes(),
    b"SucceedsSlantEqual" => "\u{227d}".as_bytes(),
    b"SucceedsTilde" => "\u{227f}".as_bytes(),
    b"SuchThat" => "\u{220b}".as_bytes(),
    b"Sum" => "\u{2211}".as_bytes(),
    b"Sup" => "\u{22d1}".as_bytes(),
    b"Superset" => "\u{2283}".as_bytes(),
    b"SupersetEqual" => "\u{2287}".as_bytes(),
    b"Supset" => "\u{22d1}".as_bytes(),
    b"THORN" => "\u{de}".as_bytes(),
    b"TRADE" => "\u{2122}".as_bytes(),
    b"TSHcy" => "\u{40b}".as_bytes(),
    b"TScy" => "\u{426}".as_bytes(),
    b"Tab" => "\u{9}".as_bytes(),
    b"Tau" => "\u{3a4}".as_bytes(),
    b"Tcaron" => "\u{164}".as_bytes(),
    b"Tcedil" => "\u{162}".as_bytes(),
    b"Tcy" => "\u{422}".as_bytes(),
    b"Tfr" => "\u{1d517}".as_bytes(),
    b"Therefore" => "\u{2234}".as_bytes(),
    b"Theta" => "\u{398}".as_bytes(),
    b"ThickSpace" => "\u{205f},\u{200a}".as_bytes(),
    b"ThinSpace" => "\u{2009}".as_bytes(),
    b"Tilde" => "\u{223c}".as_bytes(),
    b"TildeEqual" => "\u{2243}".as_bytes(),
    b"TildeFullEqual" => "\u{2245}".as_bytes(),
    b"TildeTilde" => "\u{2248}".as_bytes(),
    b"Topf" => "\u{1d54b}".as_bytes(),
    b"TripleDot" => "\u{20db}".as_bytes(),
    b"Tscr" => "\u{1d4af}".as_bytes(),
    b"Tstrok" => "\u{166}".as_bytes(),
    b"Uacute" => "\u{da}".as_bytes(),
    b"Uarr" => "\u{219f}".as_bytes(),
    b"Uarrocir" => "\u{2949}".as_bytes(),
    b"Ubrcy" => "\u{40e}".as_bytes(),
    b"Ubreve" => "\u{16c}".as_bytes(),
    b"Ucirc" => "\u{db}".as_bytes(),
    b"Ucy" => "\u{423}".as_bytes(),
    b"Udblac" => "\u{170}".as_bytes(),
    b"Ufr" => "\u{1d518}".as_bytes(),
    b"Ugrave" => "\u{d9}".as_bytes(),
    b"Umacr" => "\u{16a}".as_bytes(),
    b"UnderBar" => "\u{5f}".as_bytes(),
    b"UnderBrace" => "\u{23df}".as_bytes(),
    b"UnderBracket" => "\u{23b5}".as_bytes(),
    b"UnderParenthesis" => "\u{23dd}".as_bytes(),
    b"Union" => "\u{22c3}".as_bytes(),
    b"UnionPlus" => "\u{228e}".as_bytes(),
    b"Uogon" => "\u{172}".as_bytes(),
    b"Uopf" => "\u{1d54c}".as_bytes(),
    b"UpArrow" => "\u{2191}".as_bytes(),
    b"UpArrowBar" => "\u{2912}".as_bytes(),
    b"UpArrowDownArrow" => "\u{21c5}".as_bytes(),
    b"UpDownArrow" => "\u{2195}".as_bytes(),
    b"UpEquilibrium" => "\u{296e}".as_bytes(),
    b"UpTee" => "\u{22a5}".as_bytes(),
    b"UpTeeArrow" => "\u{21a5}".as_bytes(),
    b"Uparrow" => "\u{21d1}".as_bytes(),
    b"Updownarrow" => "\u{21d5}".as_bytes(),
    b"UpperLeftArrow" => "\u{2196}".as_bytes(),
    b"UpperRightArrow" => "\u{2197}".as_bytes(),
    b"Upsi" => "\u{3d2}".as_bytes(),
    b"Upsilon" => "\u{3a5}".as_bytes(),
    b"Uring" => "\u{16e}".as_bytes(),
    b"Uscr" => "\u{1d4b0}".as_bytes(),
    b"Utilde" => "\u{168}".as_bytes(),
    b"Uuml" => "\u{dc}".as_bytes(),
    b"VDash" => "\u{22ab}".as_bytes(),
    b"Vbar" => "\u{2aeb}".as_bytes(),
    b"Vcy" => "\u{412}".as_bytes(),
    b"Vdash" => "\u{22a9}".as_bytes(),
    b"Vdashl" => "\u{2ae6}".as_bytes(),
    b"Vee" => "\u{22c1}".as_bytes(),
    b"Verbar" => "\u{2016}".as_bytes(),
    b"Vert" => "\u{2016}".as_bytes(),
    b"VerticalBar" => "\u{2223}".as_bytes(),
    b"VerticalLine" => "\u{7c}".as_bytes(),
    b"VerticalSeparator" => "\u{2758}".as_bytes(),
    b"VerticalTilde" => "\u{2240}".as_bytes(),
    b"VeryThinSpace" => "\u{200a}".as_bytes(),
    b"Vfr" => "\u{1d519}".as_bytes(),
    b"Vopf" => "\u{1d54d}".as_bytes(),
    b"Vscr" => "\u{1d4b1}".as_bytes(),
    b"Vvdash" => "\u{22aa}".as_bytes(),
    b"Wcirc" => "\u{174}".as_bytes(),
    b"Wedge" => "\u{22c0}".as_bytes(),
    b"Wfr" => "\u{1d51a}".as_bytes(),
    b"Wopf" => "\u{1d54e}".as_bytes(),
    b"Wscr" => "\u{1d4b2}".as_bytes(),
    b"Xfr" => "\u{1d51b}".as_bytes(),
    b"Xi" => "\u{39e}".as_bytes(),
    b"Xopf" => "\u{1d54f}".as_bytes(),
    b"Xscr" => "\u{1d4b3}".as_bytes(),
    b"YAcy" => "\u{42f}".as_bytes(),
    b"YIcy" => "\u{407}".as_bytes(),
    b"YUcy" => "\u{42e}".as_bytes(),
    b"Yacute" => "\u{dd}".as_bytes(),
    b"Ycirc" => "\u{176}".as_bytes(),
    b"Ycy" => "\u{42b}".as_bytes(),
    b"Yfr" => "\u{1d51c}".as_bytes(),
    b"Yopf" => "\u{1d550}".as_bytes(),
    b"Yscr" => "\u{1d4b4}".as_bytes(),
    b"Yuml" => "\u{178}".as_bytes(),
    b"ZHcy" => "\u{416}".as_bytes(),
    b"Zacute" => "\u{179}".as_bytes(),
    b"Zcaron" => "\u{17d}".as_bytes(),
    b"Zcy" => "\u{417}".as_bytes(),
    b"Zdot" => "\u{17b}".as_bytes(),
    b"ZeroWidthSpace" => "\u{200b}".as_bytes(),
    b"Zeta" => "\u{396}".as_bytes(),
    b"Zfr" => "\u{2128}".as_bytes(),
    b"Zopf" => "\u{2124}".as_bytes(),
    b"Zscr" => "\u{1d4b5}".as_bytes(),
    b"aacute" => "\u{e1}".as_bytes(),
    b"abreve" => "\u{103}".as_bytes(),
    b"ac" => "\u{223e}".as_bytes(),
    b"acE" => "\u{223e},\u{333}".as_bytes(),
    b"acd" => "\u{223f}".as_bytes(),
    b"acirc" => "\u{e2}".as_bytes(),
    b"acute" => "\u{b4}".as_bytes(),
    b"acy" => "\u{430}".as_bytes(),
    b"aelig" => "\u{e6}".as_bytes(),
    b"af" => "\u{2061}".as_bytes(),
    b"afr" => "\u{1d51e}".as_bytes(),
    b"agrave" => "\u{e0}".as_bytes(),
    b"alefsym" => "\u{2135}".as_bytes(),
    b"aleph" => "\u{2135}".as_bytes(),
    b"alpha" => "\u{3b1}".as_bytes(),
    b"amacr" => "\u{101}".as_bytes(),
    b"amalg" => "\u{2a3f}".as_bytes(),
    b"amp" => "\u{26}".as_bytes(),
    b"and" => "\u{2227}".as_bytes(),
    b"andand" => "\u{2a55}".as_bytes(),
    b"andd" => "\u{2a5c}".as_bytes(),
    b"andslope" => "\u{2a58}".as_bytes(),
    b"andv" => "\u{2a5a}".as_bytes(),
    b"ang" => "\u{2220}".as_bytes(),
    b"ange" => "\u{29a4}".as_bytes(),
    b"angle" => "\u{2220}".as_bytes(),
    b"angmsd" => "\u{2221}".as_bytes(),
    b"angmsdaa" => "\u{29a8}".as_bytes(),
    b"angmsdab" => "\u{29a9}".as_bytes(),
    b"angmsdac" => "\u{29aa}".as_bytes(),
    b"angmsdad" => "\u{29ab}".as_bytes(),
    b"angmsdae" => "\u{29ac}".as_bytes(),
    b"angmsdaf" => "\u{29ad}".as_bytes(),
    b"angmsdag" => "\u{29ae}".as_bytes(),
    b"angmsdah" => "\u{29af}".as_bytes(),
    b"angrt" => "\u{221f}".as_bytes(),
    b"angrtvb" => "\u{22be}".as_bytes(),
    b"angrtvbd" => "\u{299d}".as_bytes(),
    b"angsph" => "\u{2222}".as_bytes(),
    b"angst" => "\u{c5}".as_bytes(),
    b"angzarr" => "\u{237c}".as_bytes(),
    b"aogon" => "\u{105}".as_bytes(),
    b"aopf" => "\u{1d552}".as_bytes(),
    b"ap" => "\u{2248}".as_bytes(),
    b"apE" => "\u{2a70}".as_bytes(),
    b"apacir" => "\u{2a6f}".as_bytes(),
    b"ape" => "\u{224a}".as_bytes(),
    b"apid" => "\u{224b}".as_bytes(),
    b"apos" => "\u{27}".as_bytes(),
    b"approx" => "\u{2248}".as_bytes(),
    b"approxeq" => "\u{224a}".as_bytes(),
    b"aring" => "\u{e5}".as_bytes(),
    b"ascr" => "\u{1d4b6}".as_bytes(),
    b"ast" => "\u{2a}".as_bytes(),
    b"asymp" => "\u{2248}".as_bytes(),
    b"asympeq" => "\u{224d}".as_bytes(),
    b"atilde" => "\u{e3}".as_bytes(),
    b"auml" => "\u{e4}".as_bytes(),
    b"awconint" => "\u{2233}".as_bytes(),
    b"awint" => "\u{2a11}".as_bytes(),
    b"bNot" => "\u{2aed}".as_bytes(),
    b"backcong" => "\u{224c}".as_bytes(),
    b"backepsilon" => "\u{3f6}".as_bytes(),
    b"backprime" => "\u{2035}".as_bytes(),
    b"backsim" => "\u{223d}".as_bytes(),
    b"backsimeq" => "\u{22cd}".as_bytes(),
    b"barvee" => "\u{22bd}".as_bytes(),
    b"barwed" => "\u{2305}".as_bytes(),
    b"barwedge" => "\u{2305}".as_bytes(),
    b"bbrk" => "\u{23b5}".as_bytes(),
    b"bbrktbrk" => "\u{23b6}".as_bytes(),
    b"bcong" => "\u{224c}".as_bytes(),
    b"bcy" => "\u{431}".as_bytes(),
    b"bdquo" => "\u{201e}".as_bytes(),
    b"becaus" => "\u{2235}".as_bytes(),
    b"because" => "\u{2235}".as_bytes(),
    b"bemptyv" => "\u{29b0}".as_bytes(),
    b"bepsi" => "\u{3f6}".as_bytes(),
    b"bernou" => "\u{212c}".as_bytes(),
    b"beta" => "\u{3b2}".as_bytes(),
    b"beth" => "\u{2136}".as_bytes(),
    b"between" => "\u{226c}".as_bytes(),
    b"bfr" => "\u{1d51f}".as_bytes(),
    b"bigcap" => "\u{22c2}".as_bytes(),
    b"bigcirc" => "\u{25ef}".as_bytes(),
    b"bigcup" => "\u{22c3}".as_bytes(),
    b"bigodot" => "\u{2a00}".as_bytes(),
    b"bigoplus" => "\u{2a01}".as_bytes(),
    b"bigotimes" => "\u{2a02}".as_bytes(),
    b"bigsqcup" => "\u{2a06}".as_bytes(),
    b"bigstar" => "\u{2605}".as_bytes(),
    b"bigtriangledown" => "\u{25bd}".as_bytes(),
    b"bigtriangleup" => "\u{25b3}".as_bytes(),
    b"biguplus" => "\u{2a04}".as_bytes(),
    b"bigvee" => "\u{22c1}".as_bytes(),
    b"bigwedge" => "\u{22c0}".as_bytes(),
    b"bkarow" => "\u{290d}".as_bytes(),
    b"blacklozenge" => "\u{29eb}".as_bytes(),
    b"blacksquare" => "\u{25aa}".as_bytes(),
    b"blacktriangle" => "\u{25b4}".as_bytes(),
    b"blacktriangledown" => "\u{25be}".as_bytes(),
    b"blacktriangleleft" => "\u{25c2}".as_bytes(),
    b"blacktriangleright" => "\u{25b8}".as_bytes(),
    b"blank" => "\u{2423}".as_bytes(),
    b"blk12" => "\u{2592}".as_bytes(),
    b"blk14" => "\u{2591}".as_bytes(),
    b"blk34" => "\u{2593}".as_bytes(),
    b"block" => "\u{2588}".as_bytes(),
    b"bne" => "\u{3d},\u{20e5}".as_bytes(),
    b"bnequiv" => "\u{2261},\u{20e5}".as_bytes(),
    b"bnot" => "\u{2310}".as_bytes(),
    b"bopf" => "\u{1d553}".as_bytes(),
    b"bot" => "\u{22a5}".as_bytes(),
    b"bottom" => "\u{22a5}".as_bytes(),
    b"bowtie" => "\u{22c8}".as_bytes(),
    b"boxDL" => "\u{2557}".as_bytes(),
    b"boxDR" => "\u{2554}".as_bytes(),
    b"boxDl" => "\u{2556}".as_bytes(),
    b"boxDr" => "\u{2553}".as_bytes(),
    b"boxH" => "\u{2550}".as_bytes(),
    b"boxHD" => "\u{2566}".as_bytes(),
    b"boxHU" => "\u{2569}".as_bytes(),
    b"boxHd" => "\u{2564}".as_bytes(),
    b"boxHu" => "\u{2567}".as_bytes(),
    b"boxUL" => "\u{255d}".as_bytes(),
    b"boxUR" => "\u{255a}".as_bytes(),
    b"boxUl" => "\u{255c}".as_bytes(),
    b"boxUr" => "\u{2559}".as_bytes(),
    b"boxV" => "\u{2551}".as_bytes(),
    b"boxVH" => "\u{256c}".as_bytes(),
    b"boxVL" => "\u{2563}".as_bytes(),
    b"boxVR" => "\u{2560}".as_bytes(),
    b"boxVh" => "\u{256b}".as_bytes(),
    b"boxVl" => "\u{2562}".as_bytes(),
    b"boxVr" => "\u{255f}".as_bytes(),
    b"boxbox" => "\u{29c9}".as_bytes(),
    b"boxdL" => "\u{2555}".as_bytes(),
    b"boxdR" => "\u{2552}".as_bytes(),
    b"boxdl" => "\u{2510}".as_bytes(),
    b"boxdr" => "\u{250c}".as_bytes(),
    b"boxh" => "\u{2500}".as_bytes(),
    b"boxhD" => "\u{2565}".as_bytes(),
    b"boxhU" => "\u{2568}".as_bytes(),
    b"boxhd" => "\u{252c}".as_bytes(),
    b"boxhu" => "\u{2534}".as_bytes(),
    b"boxminus" => "\u{229f}".as_bytes(),
    b"boxplus" => "\u{229e}".as_bytes(),
    b"boxtimes" => "\u{22a0}".as_bytes(),
    b"boxuL" => "\u{255b}".as_bytes(),
    b"boxuR" => "\u{2558}".as_bytes(),
    b"boxul" => "\u{2518}".as_bytes(),
    b"boxur" => "\u{2514}".as_bytes(),
    b"boxv" => "\u{2502}".as_bytes(),
    b"boxvH" => "\u{256a}".as_bytes(),
    b"boxvL" => "\u{2561}".as_bytes(),
    b"boxvR" => "\u{255e}".as_bytes(),
    b"boxvh" => "\u{253c}".as_bytes(),
    b"boxvl" => "\u{2524}".as_bytes(),
    b"boxvr" => "\u{251c}".as_bytes(),
    b"bprime" => "\u{2035}".as_bytes(),
    b"breve" => "\u{2d8}".as_bytes(),
    b"brvbar" => "\u{a6}".as_bytes(),
    b"bscr" => "\u{1d4b7}".as_bytes(),
    b"bsemi" => "\u{204f}".as_bytes(),
    b"bsim" => "\u{223d}".as_bytes(),
    b"bsime" => "\u{22cd}".as_bytes(),
    b"bsol" => "\u{5c}".as_bytes(),
    b"bsolb" => "\u{29c5}".as_bytes(),
    b"bsolhsub" => "\u{27c8}".as_bytes(),
    b"bull" => "\u{2022}".as_bytes(),
    b"bullet" => "\u{2022}".as_bytes(),
    b"bump" => "\u{224e}".as_bytes(),
    b"bumpE" => "\u{2aae}".as_bytes(),
    b"bumpe" => "\u{224f}".as_bytes(),
    b"bumpeq" => "\u{224f}".as_bytes(),
    b"cacute" => "\u{107}".as_bytes(),
    b"cap" => "\u{2229}".as_bytes(),
    b"capand" => "\u{2a44}".as_bytes(),
    b"capbrcup" => "\u{2a49}".as_bytes(),
    b"capcap" => "\u{2a4b}".as_bytes(),
    b"capcup" => "\u{2a47}".as_bytes(),
    b"capdot" => "\u{2a40}".as_bytes(),
    b"caps" => "\u{2229},\u{fe00}".as_bytes(),
    b"caret" => "\u{2041}".as_bytes(),
    b"caron" => "\u{2c7}".as_bytes(),
    b"ccaps" => "\u{2a4d}".as_bytes(),
    b"ccaron" => "\u{10d}".as_bytes(),
    b"ccedil" => "\u{e7}".as_bytes(),
    b"ccirc" => "\u{109}".as_bytes(),
    b"ccups" => "\u{2a4c}".as_bytes(),
    b"ccupssm" => "\u{2a50}".as_bytes(),
    b"cdot" => "\u{10b}".as_bytes(),
    b"cedil" => "\u{b8}".as_bytes(),
    b"cemptyv" => "\u{29b2}".as_bytes(),
    b"cent" => "\u{a2}".as_bytes(),
    b"centerdot" => "\u{b7}".as_bytes(),
    b"cfr" => "\u{1d520}".as_bytes(),
    b"chcy" => "\u{447}".as_bytes(),
    b"check" => "\u{2713}".as_bytes(),
    b"checkmark" => "\u{2713}".as_bytes(),
    b"chi" => "\u{3c7}".as_bytes(),
    b"cir" => "\u{25cb}".as_bytes(),
    b"cirE" => "\u{29c3}".as_bytes(),
    b"circ" => "\u{2c6}".as_bytes(),
    b"circeq" => "\u{2257}".as_bytes(),
    b"circlearrowleft" => "\u{21ba}".as_bytes(),
    b"circlearrowright" => "\u{21bb}".as_bytes(),
    b"circledR" => "\u{ae}".as_bytes(),
    b"circledS" => "\u{24c8}".as_bytes(),
    b"circledast" => "\u{229b}".as_bytes(),
    b"circledcirc" => "\u{229a}".as_bytes(),
    b"circleddash" => "\u{229d}".as_bytes(),
    b"cire" => "\u{2257}".as_bytes(),
    b"cirfnint" => "\u{2a10}".as_bytes(),
    b"cirmid" => "\u{2aef}".as_bytes(),
    b"cirscir" => "\u{29c2}".as_bytes(),
    b"clubs" => "\u{2663}".as_bytes(),
    b"clubsuit" => "\u{2663}".as_bytes(),
    b"colon" => "\u{3a}".as_bytes(),
    b"colone" => "\u{2254}".as_bytes(),
    b"coloneq" => "\u{2254}".as_bytes(),
    b"comma" => "\u{2c}".as_bytes(),
    b"commat" => "\u{40}".as_bytes(),
    b"comp" => "\u{2201}".as_bytes(),
    b"compfn" => "\u{2218}".as_bytes(),
    b"complement" => "\u{2201}".as_bytes(),
    b"complexes" => "\u{2102}".as_bytes(),
    b"cong" => "\u{2245}".as_bytes(),
    b"congdot" => "\u{2a6d}".as_bytes(),
    b"conint" => "\u{222e}".as_bytes(),
    b"copf" => "\u{1d554}".as_bytes(),
    b"coprod" => "\u{2210}".as_bytes(),
    b"copy" => "\u{a9}".as_bytes(),
    b"copysr" => "\u{2117}".as_bytes(),
    b"crarr" => "\u{21b5}".as_bytes(),
    b"cross" => "\u{2717}".as_bytes(),
    b"cscr" => "\u{1d4b8}".as_bytes(),
    b"csub" => "\u{2acf}".as_bytes(),
    b"csube" => "\u{2ad1}".as_bytes(),
    b"csup" => "\u{2ad0}".as_bytes(),
    b"csupe" => "\u{2ad2}".as_bytes(),
    b"ctdot" => "\u{22ef}".as_bytes(),
    b"cudarrl" => "\u{2938}".as_bytes(),
    b"cudarrr" => "\u{2935}".as_bytes(),
    b"cuepr" => "\u{22de}".as_bytes(),
    b"cuesc" => "\u{22df}".as_bytes(),
    b"cularr" => "\u{21b6}".as_bytes(),
    b"cularrp" => "\u{293d}".as_bytes(),
    b"cup" => "\u{222a}".as_bytes(),
    b"cupbrcap" => "\u{2a48}".as_bytes(),
    b"cupcap" => "\u{2a46}".as_bytes(),
    b"cupcup" => "\u{2a4a}".as_bytes(),
    b"cupdot" => "\u{228d}".as_bytes(),
    b"cupor" => "\u{2a45}".as_bytes(),
    b"cups" => "\u{222a},\u{fe00}".as_bytes(),
    b"curarr" => "\u{21b7}".as_bytes(),
    b"curarrm" => "\u{293c}".as_bytes(),
    b"curlyeqprec" => "\u{22de}".as_bytes(),
    b"curlyeqsucc" => "\u{22df}".as_bytes(),
    b"curlyvee" => "\u{22ce}".as_bytes(),
    b"curlywedge" => "\u{22cf}".as_bytes(),
    b"curren" => "\u{a4}".as_bytes(),
    b"curvearrowleft" => "\u{21b6}".as_bytes(),
    b"curvearrowright" => "\u{21b7}".as_bytes(),
    b"cuvee" => "\u{22ce}".as_bytes(),
    b"cuwed" => "\u{22cf}".as_bytes(),
    b"cwconint" => "\u{2232}".as_bytes(),
    b"cwint" => "\u{2231}".as_bytes(),
    b"cylcty" => "\u{232d}".as_bytes(),
    b"dArr" => "\u{21d3}".as_bytes(),
    b"dHar" => "\u{2965}".as_bytes(),
    b"dagger" => "\u{2020}".as_bytes(),
    b"daleth" => "\u{2138}".as_bytes(),
    b"darr" => "\u{2193}".as_bytes(),
    b"dash" => "\u{2010}".as_bytes(),
    b"dashv" => "\u{22a3}".as_bytes(),
    b"dbkarow" => "\u{290f}".as_bytes(),
    b"dblac" => "\u{2dd}".as_bytes(),
    b"dcaron" => "\u{10f}".as_bytes(),
    b"dcy" => "\u{434}".as_bytes(),
    b"dd" => "\u{2146}".as_bytes(),
    b"ddagger" => "\u{2021}".as_bytes(),
    b"ddarr" => "\u{21ca}".as_bytes(),
    b"ddotseq" => "\u{2a77}".as_bytes(),
    b"deg" => "\u{b0}".as_bytes(),
    b"delta" => "\u{3b4}".as_bytes(),
    b"demptyv" => "\u{29b1}".as_bytes(),
    b"dfisht" => "\u{297f}".as_bytes(),
    b"dfr" => "\u{1d521}".as_bytes(),
    b"dharl" => "\u{21c3}".as_bytes(),
    b"dharr" => "\u{21c2}".as_bytes(),
    b"diam" => "\u{22c4}".as_bytes(),
    b"diamond" => "\u{22c4}".as_bytes(),
    b"diamondsuit" => "\u{2666}".as_bytes(),
    b"diams" => "\u{2666}".as_bytes(),
    b"die" => "\u{a8}".as_bytes(),
    b"digamma" => "\u{3dd}".as_bytes(),
    b"disin" => "\u{22f2}".as_bytes(),
    b"div" => "\u{f7}".as_bytes(),
    b"divide" => "\u{f7}".as_bytes(),
    b"divideontimes" => "\u{22c7}".as_bytes(),
    b"divonx" => "\u{22c7}".as_bytes(),
    b"djcy" => "\u{452}".as_bytes(),
    b"dlcorn" => "\u{231e}".as_bytes(),
    b"dlcrop" => "\u{230d}".as_bytes(),
    b"dollar" => "\u{24}".as_bytes(),
    b"dopf" => "\u{1d555}".as_bytes(),
    b"dot" => "\u{2d9}".as_bytes(),
    b"doteq" => "\u{2250}".as_bytes(),
    b"doteqdot" => "\u{2251}".as_bytes(),
    b"dotminus" => "\u{2238}".as_bytes(),
    b"dotplus" => "\u{2214}".as_bytes(),
    b"dotsquare" => "\u{22a1}".as_bytes(),
    b"doublebarwedge" => "\u{2306}".as_bytes(),
    b"downarrow" => "\u{2193}".as_bytes(),
    b"downdownarrows" => "\u{21ca}".as_bytes(),
    b"downharpoonleft" => "\u{21c3}".as_bytes(),
    b"downharpoonright" => "\u{21c2}".as_bytes(),
    b"drbkarow" => "\u{2910}".as_bytes(),
    b"drcorn" => "\u{231f}".as_bytes(),
    b"drcrop" => "\u{230c}".as_bytes(),
    b"dscr" => "\u{1d4b9}".as_bytes(),
    b"dscy" => "\u{455}".as_bytes(),
    b"dsol" => "\u{29f6}".as_bytes(),
    b"dstrok" => "\u{111}".as_bytes(),
    b"dtdot" => "\u{22f1}".as_bytes(),
    b"dtri" => "\u{25bf}".as_bytes(),
    b"dtrif" => "\u{25be}".as_bytes(),
    b"duarr" => "\u{21f5}".as_bytes(),
    b"duhar" => "\u{296f}".as_bytes(),
    b"dwangle" => "\u{29a6}".as_bytes(),
    b"dzcy" => "\u{45f}".as_bytes(),
    b"dzigrarr" => "\u{27ff}".as_bytes(),
    b"eDDot" => "\u{2a77}".as_bytes(),
    b"eDot" => "\u{2251}".as_bytes(),
    b"eacute" => "\u{e9}".as_bytes(),
    b"easter" => "\u{2a6e}".as_bytes(),
    b"ecaron" => "\u{11b}".as_bytes(),
    b"ecir" => "\u{2256}".as_bytes(),
    b"ecirc" => "\u{ea}".as_bytes(),
    b"ecolon" => "\u{2255}".as_bytes(),
    b"ecy" => "\u{44d}".as_bytes(),
    b"edot" => "\u{117}".as_bytes(),
    b"ee" => "\u{2147}".as_bytes(),
    b"efDot" => "\u{2252}".as_bytes(),
    b"efr" => "\u{1d522}".as_bytes(),
    b"eg" => "\u{2a9a}".as_bytes(),
    b"egrave" => "\u{e8}".as_bytes(),
    b"egs" => "\u{2a96}".as_bytes(),
    b"egsdot" => "\u{2a98}".as_bytes(),
    b"el" => "\u{2a99}".as_bytes(),
    b"elinters" => "\u{23e7}".as_bytes(),
    b"ell" => "\u{2113}".as_bytes(),
    b"els" => "\u{2a95}".as_bytes(),
    b"elsdot" => "\u{2a97}".as_bytes(),
    b"emacr" => "\u{113}".as_bytes(),
    b"empty" => "\u{2205}".as_bytes(),
    b"emptyset" => "\u{2205}".as_bytes(),
    b"emptyv" => "\u{2205}".as_bytes(),
    b"emsp13" => "\u{2004}".as_bytes(),
    b"emsp14" => "\u{2005}".as_bytes(),
    b"emsp" => "\u{2003}".as_bytes(),
    b"eng" => "\u{14b}".as_bytes(),
    b"ensp" => "\u{2002}".as_bytes(),
    b"eogon" => "\u{119}".as_bytes(),
    b"eopf" => "\u{1d556}".as_bytes(),
    b"epar" => "\u{22d5}".as_bytes(),
    b"eparsl" => "\u{29e3}".as_bytes(),
    b"eplus" => "\u{2a71}".as_bytes(),
    b"epsi" => "\u{3b5}".as_bytes(),
    b"epsilon" => "\u{3b5}".as_bytes(),
    b"epsiv" => "\u{3f5}".as_bytes(),
    b"eqcirc" => "\u{2256}".as_bytes(),
    b"eqcolon" => "\u{2255}".as_bytes(),
    b"eqsim" => "\u{2242}".as_bytes(),
    b"eqslantgtr" => "\u{2a96}".as_bytes(),
    b"eqslantless" => "\u{2a95}".as_bytes(),
    b"equals" => "\u{3d}".as_bytes(),
    b"equest" => "\u{225f}".as_bytes(),
    b"equiv" => "\u{2261}".as_bytes(),
    b"equivDD" => "\u{2a78}".as_bytes(),
    b"eqvparsl" => "\u{29e5}".as_bytes(),
    b"erDot" => "\u{2253}".as_bytes(),
    b"erarr" => "\u{2971}".as_bytes(),
    b"escr" => "\u{212f}".as_bytes(),
    b"esdot" => "\u{2250}".as_bytes(),
    b"esim" => "\u{2242}".as_bytes(),
    b"eta" => "\u{3b7}".as_bytes(),
    b"eth" => "\u{f0}".as_bytes(),
    b"euml" => "\u{eb}".as_bytes(),
    b"euro" => "\u{20ac}".as_bytes(),
    b"excl" => "\u{21}".as_bytes(),
    b"exist" => "\u{2203}".as_bytes(),
    b"expectation" => "\u{2130}".as_bytes(),
    b"exponentiale" => "\u{2147}".as_bytes(),
    b"fallingdotseq" => "\u{2252}".as_bytes(),
    b"fcy" => "\u{444}".as_bytes(),
    b"female" => "\u{2640}".as_bytes(),
    b"ffilig" => "\u{fb03}".as_bytes(),
    b"fflig" => "\u{fb00}".as_bytes(),
    b"ffllig" => "\u{fb04}".as_bytes(),
    b"ffr" => "\u{1d523}".as_bytes(),
    b"filig" => "\u{fb01}".as_bytes(),
    b"fjlig" => "\u{66},\u{6a}".as_bytes(),
    b"flat" => "\u{266d}".as_bytes(),
    b"fllig" => "\u{fb02}".as_bytes(),
    b"fltns" => "\u{25b1}".as_bytes(),
    b"fnof" => "\u{192}".as_bytes(),
    b"fopf" => "\u{1d557}".as_bytes(),
    b"forall" => "\u{2200}".as_bytes(),
    b"fork" => "\u{22d4}".as_bytes(),
    b"forkv" => "\u{2ad9}".as_bytes(),
    b"fpartint" => "\u{2a0d}".as_bytes(),
    b"frac12" => "\u{bd}".as_bytes(),
    b"frac13" => "\u{2153}".as_bytes(),
    b"frac14" => "\u{bc}".as_bytes(),
    b"frac15" => "\u{2155}".as_bytes(),
    b"frac16" => "\u{2159}".as_bytes(),
    b"frac18" => "\u{215b}".as_bytes(),
    b"frac23" => "\u{2154}".as_bytes(),
    b"frac25" => "\u{2156}".as_bytes(),
    b"frac34" => "\u{be}".as_bytes(),
    b"frac35" => "\u{2157}".as_bytes(),
    b"frac38" => "\u{215c}".as_bytes(),
    b"frac45" => "\u{2158}".as_bytes(),
    b"frac56" => "\u{215a}".as_bytes(),
    b"frac58" => "\u{215d}".as_bytes(),
    b"frac78" => "\u{215e}".as_bytes(),
    b"frasl" => "\u{2044}".as_bytes(),
    b"frown" => "\u{2322}".as_bytes(),
    b"fscr" => "\u{1d4bb}".as_bytes(),
    b"gE" => "\u{2267}".as_bytes(),
    b"gEl" => "\u{2a8c}".as_bytes(),
    b"gacute" => "\u{1f5}".as_bytes(),
    b"gamma" => "\u{3b3}".as_bytes(),
    b"gammad" => "\u{3dd}".as_bytes(),
    b"gap" => "\u{2a86}".as_bytes(),
    b"gbreve" => "\u{11f}".as_bytes(),
    b"gcirc" => "\u{11d}".as_bytes(),
    b"gcy" => "\u{433}".as_bytes(),
    b"gdot" => "\u{121}".as_bytes(),
    b"ge" => "\u{2265}".as_bytes(),
    b"gel" => "\u{22db}".as_bytes(),
    b"geq" => "\u{2265}".as_bytes(),
    b"geqq" => "\u{2267}".as_bytes(),
    b"geqslant" => "\u{2a7e}".as_bytes(),
    b"ges" => "\u{2a7e}".as_bytes(),
    b"gescc" => "\u{2aa9}".as_bytes(),
    b"gesdot" => "\u{2a80}".as_bytes(),
    b"gesdoto" => "\u{2a82}".as_bytes(),
    b"gesdotol" => "\u{2a84}".as_bytes(),
    b"gesl" => "\u{22db},\u{fe00}".as_bytes(),
    b"gesles" => "\u{2a94}".as_bytes(),
    b"gfr" => "\u{1d524}".as_bytes(),
    b"gg" => "\u{226b}".as_bytes(),
    b"ggg" => "\u{22d9}".as_bytes(),
    b"gimel" => "\u{2137}".as_bytes(),
    b"gjcy" => "\u{453}".as_bytes(),
    b"gl" => "\u{2277}".as_bytes(),
    b"glE" => "\u{2a92}".as_bytes(),
    b"gla" => "\u{2aa5}".as_bytes(),
    b"glj" => "\u{2aa4}".as_bytes(),
    b"gnE" => "\u{2269}".as_bytes(),
    b"gnap" => "\u{2a8a}".as_bytes(),
    b"gnapprox" => "\u{2a8a}".as_bytes(),
    b"gne" => "\u{2a88}".as_bytes(),
    b"gneq" => "\u{2a88}".as_bytes(),
    b"gneqq" => "\u{2269}".as_bytes(),
    b"gnsim" => "\u{22e7}".as_bytes(),
    b"gopf" => "\u{1d558}".as_bytes(),
    b"grave" => "\u{60}".as_bytes(),
    b"gscr" => "\u{210a}".as_bytes(),
    b"gsim" => "\u{2273}".as_bytes(),
    b"gsime" => "\u{2a8e}".as_bytes(),
    b"gsiml" => "\u{2a90}".as_bytes(),
    b"gt" => "\u{3e}".as_bytes(),
    b"gtcc" => "\u{2aa7}".as_bytes(),
    b"gtcir" => "\u{2a7a}".as_bytes(),
    b"gtdot" => "\u{22d7}".as_bytes(),
    b"gtlPar" => "\u{2995}".as_bytes(),
    b"gtquest" => "\u{2a7c}".as_bytes(),
    b"gtrapprox" => "\u{2a86}".as_bytes(),
    b"gtrarr" => "\u{2978}".as_bytes(),
    b"gtrdot" => "\u{22d7}".as_bytes(),
    b"gtreqless" => "\u{22db}".as_bytes(),
    b"gtreqqless" => "\u{2a8c}".as_bytes(),
    b"gtrless" => "\u{2277}".as_bytes(),
    b"gtrsim" => "\u{2273}".as_bytes(),
    b"gvertneqq" => "\u{2269},\u{fe00}".as_bytes(),
    b"gvnE" => "\u{2269},\u{fe00}".as_bytes(),
    b"hArr" => "\u{21d4}".as_bytes(),
    b"hairsp" => "\u{200a}".as_bytes(),
    b"half" => "\u{bd}".as_bytes(),
    b"hamilt" => "\u{210b}".as_bytes(),
    b"hardcy" => "\u{44a}".as_bytes(),
    b"harr" => "\u{2194}".as_bytes(),
    b"harrcir" => "\u{2948}".as_bytes(),
    b"harrw" => "\u{21ad}".as_bytes(),
    b"hbar" => "\u{210f}".as_bytes(),
    b"hcirc" => "\u{125}".as_bytes(),
    b"hearts" => "\u{2665}".as_bytes(),
    b"heartsuit" => "\u{2665}".as_bytes(),
    b"hellip" => "\u{2026}".as_bytes(),
    b"hercon" => "\u{22b9}".as_bytes(),
    b"hfr" => "\u{1d525}".as_bytes(),
    b"hksearow" => "\u{2925}".as_bytes(),
    b"hkswarow" => "\u{2926}".as_bytes(),
    b"hoarr" => "\u{21ff}".as_bytes(),
    b"homtht" => "\u{223b}".as_bytes(),
    b"hookleftarrow" => "\u{21a9}".as_bytes(),
    b"hookrightarrow" => "\u{21aa}".as_bytes(),
    b"hopf" => "\u{1d559}".as_bytes(),
    b"horbar" => "\u{2015}".as_bytes(),
    b"hscr" => "\u{1d4bd}".as_bytes(),
    b"hslash" => "\u{210f}".as_bytes(),
    b"hstrok" => "\u{127}".as_bytes(),
    b"hybull" => "\u{2043}".as_bytes(),
    b"hyphen" => "\u{2010}".as_bytes(),
    b"iacute" => "\u{ed}".as_bytes(),
    b"ic" => "\u{2063}".as_bytes(),
    b"icirc" => "\u{ee}".as_bytes(),
    b"icy" => "\u{438}".as_bytes(),
    b"iecy" => "\u{435}".as_bytes(),
    b"iexcl" => "\u{a1}".as_bytes(),
    b"iff" => "\u{21d4}".as_bytes(),
    b"ifr" => "\u{1d526}".as_bytes(),
    b"igrave" => "\u{ec}".as_bytes(),
    b"ii" => "\u{2148}".as_bytes(),
    b"iiiint" => "\u{2a0c}".as_bytes(),
    b"iiint" => "\u{222d}".as_bytes(),
    b"iinfin" => "\u{29dc}".as_bytes(),
    b"iiota" => "\u{2129}".as_bytes(),
    b"ijlig" => "\u{133}".as_bytes(),
    b"imacr" => "\u{12b}".as_bytes(),
    b"image" => "\u{2111}".as_bytes(),
    b"imagline" => "\u{2110}".as_bytes(),
    b"imagpart" => "\u{2111}".as_bytes(),
    b"imath" => "\u{131}".as_bytes(),
    b"imof" => "\u{22b7}".as_bytes(),
    b"imped" => "\u{1b5}".as_bytes(),
    b"in" => "\u{2208}".as_bytes(),
    b"incare" => "\u{2105}".as_bytes(),
    b"infin" => "\u{221e}".as_bytes(),
    b"infintie" => "\u{29dd}".as_bytes(),
    b"inodot" => "\u{131}".as_bytes(),
    b"int" => "\u{222b}".as_bytes(),
    b"intcal" => "\u{22ba}".as_bytes(),
    b"integers" => "\u{2124}".as_bytes(),
    b"intercal" => "\u{22ba}".as_bytes(),
    b"intlarhk" => "\u{2a17}".as_bytes(),
    b"intprod" => "\u{2a3c}".as_bytes(),
    b"iocy" => "\u{451}".as_bytes(),
    b"iogon" => "\u{12f}".as_bytes(),
    b"iopf" => "\u{1d55a}".as_bytes(),
    b"iota" => "\u{3b9}".as_bytes(),
    b"iprod" => "\u{2a3c}".as_bytes(),
    b"iquest" => "\u{bf}".as_bytes(),
    b"iscr" => "\u{1d4be}".as_bytes(),
    b"isin" => "\u{2208}".as_bytes(),
    b"isinE" => "\u{22f9}".as_bytes(),
    b"isindot" => "\u{22f5}".as_bytes(),
    b"isins" => "\u{22f4}".as_bytes(),
    b"isinsv" => "\u{22f3}".as_bytes(),
    b"isinv" => "\u{2208}".as_bytes(),
    b"it" => "\u{2062}".as_bytes(),
    b"itilde" => "\u{129}".as_bytes(),
    b"iukcy" => "\u{456}".as_bytes(),
    b"iuml" => "\u{ef}".as_bytes(),
    b"jcirc" => "\u{135}".as_bytes(),
    b"jcy" => "\u{439}".as_bytes(),
    b"jfr" => "\u{1d527}".as_bytes(),
    b"jmath" => "\u{237}".as_bytes(),
    b"jopf" => "\u{1d55b}".as_bytes(),
    b"jscr" => "\u{1d4bf}".as_bytes(),
    b"jsercy" => "\u{458}".as_bytes(),
    b"jukcy" => "\u{454}".as_bytes(),
    b"kappa" => "\u{3ba}".as_bytes(),
    b"kappav" => "\u{3f0}".as_bytes(),
    b"kcedil" => "\u{137}".as_bytes(),
    b"kcy" => "\u{43a}".as_bytes(),
    b"kfr" => "\u{1d528}".as_bytes(),
    b"kgreen" => "\u{138}".as_bytes(),
    b"khcy" => "\u{445}".as_bytes(),
    b"kjcy" => "\u{45c}".as_bytes(),
    b"kopf" => "\u{1d55c}".as_bytes(),
    b"kscr" => "\u{1d4c0}".as_bytes(),
    b"lAarr" => "\u{21da}".as_bytes(),
    b"lArr" => "\u{21d0}".as_bytes(),
    b"lAtail" => "\u{291b}".as_bytes(),
    b"lBarr" => "\u{290e}".as_bytes(),
    b"lE" => "\u{2266}".as_bytes(),
    b"lEg" => "\u{2a8b}".as_bytes(),
    b"lHar" => "\u{2962}".as_bytes(),
    b"lacute" => "\u{13a}".as_bytes(),
    b"laemptyv" => "\u{29b4}".as_bytes(),
    b"lagran" => "\u{2112}".as_bytes(),
    b"lambda" => "\u{3bb}".as_bytes(),
    b"lang" => "\u{27e8}".as_bytes(),
    b"langd" => "\u{2991}".as_bytes(),
    b"langle" => "\u{27e8}".as_bytes(),
    b"lap" => "\u{2a85}".as_bytes(),
    b"laquo" => "\u{ab}".as_bytes(),
    b"larr" => "\u{2190}".as_bytes(),
    b"larrb" => "\u{21e4}".as_bytes(),
    b"larrbfs" => "\u{291f}".as_bytes(),
    b"larrfs" => "\u{291d}".as_bytes(),
    b"larrhk" => "\u{21a9}".as_bytes(),
    b"larrlp" => "\u{21ab}".as_bytes(),
    b"larrpl" => "\u{2939}".as_bytes(),
    b"larrsim" => "\u{2973}".as_bytes(),
    b"larrtl" => "\u{21a2}".as_bytes(),
    b"lat" => "\u{2aab}".as_bytes(),
    b"latail" => "\u{2919}".as_bytes(),
    b"late" => "\u{2aad}".as_bytes(),
    b"lates" => "\u{2aad},\u{fe00}".as_bytes(),
    b"lbarr" => "\u{290c}".as_bytes(),
    b"lbbrk" => "\u{2772}".as_bytes(),
    b"lbrace" => "\u{7b}".as_bytes(),
    b"lbrack" => "\u{5b}".as_bytes(),
    b"lbrke" => "\u{298b}".as_bytes(),
    b"lbrksld" => "\u{298f}".as_bytes(),
    b"lbrkslu" => "\u{298d}".as_bytes(),
    b"lcaron" => "\u{13e}".as_bytes(),
    b"lcedil" => "\u{13c}".as_bytes(),
    b"lceil" => "\u{2308}".as_bytes(),
    b"lcub" => "\u{7b}".as_bytes(),
    b"lcy" => "\u{43b}".as_bytes(),
    b"ldca" => "\u{2936}".as_bytes(),
    b"ldquo" => "\u{201c}".as_bytes(),
    b"ldquor" => "\u{201e}".as_bytes(),
    b"ldrdhar" => "\u{2967}".as_bytes(),
    b"ldrushar" => "\u{294b}".as_bytes(),
    b"ldsh" => "\u{21b2}".as_bytes(),
    b"le" => "\u{2264}".as_bytes(),
    b"leftarrow" => "\u{2190}".as_bytes(),
    b"leftarrowtail" => "\u{21a2}".as_bytes(),
    b"leftharpoondown" => "\u{21bd}".as_bytes(),
    b"leftharpoonup" => "\u{21bc}".as_bytes(),
    b"leftleftarrows" => "\u{21c7}".as_bytes(),
    b"leftrightarrow" => "\u{2194}".as_bytes(),
    b"leftrightarrows" => "\u{21c6}".as_bytes(),
    b"leftrightharpoons" => "\u{21cb}".as_bytes(),
    b"leftrightsquigarrow" => "\u{21ad}".as_bytes(),
    b"leftthreetimes" => "\u{22cb}".as_bytes(),
    b"leg" => "\u{22da}".as_bytes(),
    b"leq" => "\u{2264}".as_bytes(),
    b"leqq" => "\u{2266}".as_bytes(),
    b"leqslant" => "\u{2a7d}".as_bytes(),
    b"les" => "\u{2a7d}".as_bytes(),
    b"lescc" => "\u{2aa8}".as_bytes(),
    b"lesdot" => "\u{2a7f}".as_bytes(),
    b"lesdoto" => "\u{2a81}".as_bytes(),
    b"lesdotor" => "\u{2a83}".as_bytes(),
    b"lesg" => "\u{22da},\u{fe00}".as_bytes(),
    b"lesges" => "\u{2a93}".as_bytes(),
    b"lessapprox" => "\u{2a85}".as_bytes(),
    b"lessdot" => "\u{22d6}".as_bytes(),
    b"lesseqgtr" => "\u{22da}".as_bytes(),
    b"lesseqqgtr" => "\u{2a8b}".as_bytes(),
    b"lessgtr" => "\u{2276}".as_bytes(),
    b"lesssim" => "\u{2272}".as_bytes(),
    b"lfisht" => "\u{297c}".as_bytes(),
    b"lfloor" => "\u{230a}".as_bytes(),
    b"lfr" => "\u{1d529}".as_bytes(),
    b"lg" => "\u{2276}".as_bytes(),
    b"lgE" => "\u{2a91}".as_bytes(),
    b"lhard" => "\u{21bd}".as_bytes(),
    b"lharu" => "\u{21bc}".as_bytes(),
    b"lharul" => "\u{296a}".as_bytes(),
    b"lhblk" => "\u{2584}".as_bytes(),
    b"ljcy" => "\u{459}".as_bytes(),
    b"ll" => "\u{226a}".as_bytes(),
    b"llarr" => "\u{21c7}".as_bytes(),
    b"llcorner" => "\u{231e}".as_bytes(),
    b"llhard" => "\u{296b}".as_bytes(),
    b"lltri" => "\u{25fa}".as_bytes(),
    b"lmidot" => "\u{140}".as_bytes(),
    b"lmoust" => "\u{23b0}".as_bytes(),
    b"lmoustache" => "\u{23b0}".as_bytes(),
    b"lnE" => "\u{2268}".as_bytes(),
    b"lnap" => "\u{2a89}".as_bytes(),
    b"lnapprox" => "\u{2a89}".as_bytes(),
    b"lne" => "\u{2a87}".as_bytes(),
    b"lneq" => "\u{2a87}".as_bytes(),
    b"lneqq" => "\u{2268}".as_bytes(),
    b"lnsim" => "\u{22e6}".as_bytes(),
    b"loang" => "\u{27ec}".as_bytes(),
    b"loarr" => "\u{21fd}".as_bytes(),
    b"lobrk" => "\u{27e6}".as_bytes(),
    b"longleftarrow" => "\u{27f5}".as_bytes(),
    b"longleftrightarrow" => "\u{27f7}".as_bytes(),
    b"longmapsto" => "\u{27fc}".as_bytes(),
    b"longrightarrow" => "\u{27f6}".as_bytes(),
    b"looparrowleft" => "\u{21ab}".as_bytes(),
    b"looparrowright" => "\u{21ac}".as_bytes(),
    b"lopar" => "\u{2985}".as_bytes(),
    b"lopf" => "\u{1d55d}".as_bytes(),
    b"loplus" => "\u{2a2d}".as_bytes(),
    b"lotimes" => "\u{2a34}".as_bytes(),
    b"lowast" => "\u{2217}".as_bytes(),
    b"lowbar" => "\u{5f}".as_bytes(),
    b"loz" => "\u{25ca}".as_bytes(),
    b"lozenge" => "\u{25ca}".as_bytes(),
    b"lozf" => "\u{29eb}".as_bytes(),
    b"lpar" => "\u{28}".as_bytes(),
    b"lparlt" => "\u{2993}".as_bytes(),
    b"lrarr" => "\u{21c6}".as_bytes(),
    b"lrcorner" => "\u{231f}".as_bytes(),
    b"lrhar" => "\u{21cb}".as_bytes(),
    b"lrhard" => "\u{296d}".as_bytes(),
    b"lrm" => "\u{200e}".as_bytes(),
    b"lrtri" => "\u{22bf}".as_bytes(),
    b"lsaquo" => "\u{2039}".as_bytes(),
    b"lscr" => "\u{1d4c1}".as_bytes(),
    b"lsh" => "\u{21b0}".as_bytes(),
    b"lsim" => "\u{2272}".as_bytes(),
    b"lsime" => "\u{2a8d}".as_bytes(),
    b"lsimg" => "\u{2a8f}".as_bytes(),
    b"lsqb" => "\u{5b}".as_bytes(),
    b"lsquo" => "\u{2018}".as_bytes(),
    b"lsquor" => "\u{201a}".as_bytes(),
    b"lstrok" => "\u{142}".as_bytes(),
    b"lt" => "\u{3c}".as_bytes(),
    b"ltcc" => "\u{2aa6}".as_bytes(),
    b"ltcir" => "\u{2a79}".as_bytes(),
    b"ltdot" => "\u{22d6}".as_bytes(),
    b"lthree" => "\u{22cb}".as_bytes(),
    b"ltimes" => "\u{22c9}".as_bytes(),
    b"ltlarr" => "\u{2976}".as_bytes(),
    b"ltquest" => "\u{2a7b}".as_bytes(),
    b"ltrPar" => "\u{2996}".as_bytes(),
    b"ltri" => "\u{25c3}".as_bytes(),
    b"ltrie" => "\u{22b4}".as_bytes(),
    b"ltrif" => "\u{25c2}".as_bytes(),
    b"lurdshar" => "\u{294a}".as_bytes(),
    b"luruhar" => "\u{2966}".as_bytes(),
    b"lvertneqq" => "\u{2268},\u{fe00}".as_bytes(),
    b"lvnE" => "\u{2268},\u{fe00}".as_bytes(),
    b"mDDot" => "\u{223a}".as_bytes(),
    b"macr" => "\u{af}".as_bytes(),
    b"male" => "\u{2642}".as_bytes(),
    b"malt" => "\u{2720}".as_bytes(),
    b"maltese" => "\u{2720}".as_bytes(),
    b"map" => "\u{21a6}".as_bytes(),
    b"mapsto" => "\u{21a6}".as_bytes(),
    b"mapstodown" => "\u{21a7}".as_bytes(),
    b"mapstoleft" => "\u{21a4}".as_bytes(),
    b"mapstoup" => "\u{21a5}".as_bytes(),
    b"marker" => "\u{25ae}".as_bytes(),
    b"mcomma" => "\u{2a29}".as_bytes(),
    b"mcy" => "\u{43c}".as_bytes(),
    b"mdash" => "\u{2014}".as_bytes(),
    b"measuredangle" => "\u{2221}".as_bytes(),
    b"mfr" => "\u{1d52a}".as_bytes(),
    b"mho" => "\u{2127}".as_bytes(),
    b"micro" => "\u{b5}".as_bytes(),
    b"mid" => "\u{2223}".as_bytes(),
    b"midast" => "\u{2a}".as_bytes(),
    b"midcir" => "\u{2af0}".as_bytes(),
    b"middot" => "\u{b7}".as_bytes(),
    b"minus" => "\u{2212}".as_bytes(),
    b"minusb" => "\u{229f}".as_bytes(),
    b"minusd" => "\u{2238}".as_bytes(),
    b"minusdu" => "\u{2a2a}".as_bytes(),
    b"mlcp" => "\u{2adb}".as_bytes(),
    b"mldr" => "\u{2026}".as_bytes(),
    b"mnplus" => "\u{2213}".as_bytes(),
    b"models" => "\u{22a7}".as_bytes(),
    b"mopf" => "\u{1d55e}".as_bytes(),
    b"mp" => "\u{2213}".as_bytes(),
    b"mscr" => "\u{1d4c2}".as_bytes(),
    b"mstpos" => "\u{223e}".as_bytes(),
    b"mu" => "\u{3bc}".as_bytes(),
    b"multimap" => "\u{22b8}".as_bytes(),
    b"mumap" => "\u{22b8}".as_bytes(),
    b"nGg" => "\u{22d9},\u{338}".as_bytes(),
    b"nGt" => "\u{226b},\u{20d2}".as_bytes(),
    b"nGtv" => "\u{226b},\u{338}".as_bytes(),
    b"nLeftarrow" => "\u{21cd}".as_bytes(),
    b"nLeftrightarrow" => "\u{21ce}".as_bytes(),
    b"nLl" => "\u{22d8},\u{338}".as_bytes(),
    b"nLt" => "\u{226a},\u{20d2}".as_bytes(),
    b"nLtv" => "\u{226a},\u{338}".as_bytes(),
    b"nRightarrow" => "\u{21cf}".as_bytes(),
    b"nVDash" => "\u{22af}".as_bytes(),
    b"nVdash" => "\u{22ae}".as_bytes(),
    b"nabla" => "\u{2207}".as_bytes(),
    b"nacute" => "\u{144}".as_bytes(),
    b"nang" => "\u{2220},\u{20d2}".as_bytes(),
    b"nap" => "\u{2249}".as_bytes(),
    b"napE" => "\u{2a70},\u{338}".as_bytes(),
    b"napid" => "\u{224b},\u{338}".as_bytes(),
    b"napos" => "\u{149}".as_bytes(),
    b"napprox" => "\u{2249}".as_bytes(),
    b"natur" => "\u{266e}".as_bytes(),
    b"natural" => "\u{266e}".as_bytes(),
    b"naturals" => "\u{2115}".as_bytes(),
    b"nbsp" => "\u{a0}".as_bytes(),
    b"nbump" => "\u{224e},\u{338}".as_bytes(),
    b"nbumpe" => "\u{224f},\u{338}".as_bytes(),
    b"ncap" => "\u{2a43}".as_bytes(),
    b"ncaron" => "\u{148}".as_bytes(),
    b"ncedil" => "\u{146}".as_bytes(),
    b"ncong" => "\u{2247}".as_bytes(),
    b"ncongdot" => "\u{2a6d},\u{338}".as_bytes(),
    b"ncup" => "\u{2a42}".as_bytes(),
    b"ncy" => "\u{43d}".as_bytes(),
    b"ndash" => "\u{2013}".as_bytes(),
    b"ne" => "\u{2260}".as_bytes(),
    b"neArr" => "\u{21d7}".as_bytes(),
    b"nearhk" => "\u{2924}".as_bytes(),
    b"nearr" => "\u{2197}".as_bytes(),
    b"nearrow" => "\u{2197}".as_bytes(),
    b"nedot" => "\u{2250},\u{338}".as_bytes(),
    b"nequiv" => "\u{2262}".as_bytes(),
    b"nesear" => "\u{2928}".as_bytes(),
    b"nesim" => "\u{2242},\u{338}".as_bytes(),
    b"nexist" => "\u{2204}".as_bytes(),
    b"nexists" => "\u{2204}".as_bytes(),
    b"nfr" => "\u{1d52b}".as_bytes(),
    b"ngE" => "\u{2267},\u{338}".as_bytes(),
    b"nge" => "\u{2271}".as_bytes(),
    b"ngeq" => "\u{2271}".as_bytes(),
    b"ngeqq" => "\u{2267},\u{338}".as_bytes(),
    b"ngeqslant" => "\u{2a7e},\u{338}".as_bytes(),
    b"nges" => "\u{2a7e},\u{338}".as_bytes(),
    b"ngsim" => "\u{2275}".as_bytes(),
    b"ngt" => "\u{226f}".as_bytes(),
    b"ngtr" => "\u{226f}".as_bytes(),
    b"nhArr" => "\u{21ce}".as_bytes(),
    b"nharr" => "\u{21ae}".as_bytes(),
    b"nhpar" => "\u{2af2}".as_bytes(),
    b"ni" => "\u{220b}".as_bytes(),
    b"nis" => "\u{22fc}".as_bytes(),
    b"nisd" => "\u{22fa}".as_bytes(),
    b"niv" => "\u{220b}".as_bytes(),
    b"njcy" => "\u{45a}".as_bytes(),
    b"nlArr" => "\u{21cd}".as_bytes(),
    b"nlE" => "\u{2266},\u{338}".as_bytes(),
    b"nlarr" => "\u{219a}".as_bytes(),
    b"nldr" => "\u{2025}".as_bytes(),
    b"nle" => "\u{2270}".as_bytes(),
    b"nleftarrow" => "\u{219a}".as_bytes(),
    b"nleftrightarrow" => "\u{21ae}".as_bytes(),
    b"nleq" => "\u{2270}".as_bytes(),
    b"nleqq" => "\u{2266},\u{338}".as_bytes(),
    b"nleqslant" => "\u{2a7d},\u{338}".as_bytes(),
    b"nles" => "\u{2a7d},\u{338}".as_bytes(),
    b"nless" => "\u{226e}".as_bytes(),
    b"nlsim" => "\u{2274}".as_bytes(),
    b"nlt" => "\u{226e}".as_bytes(),
    b"nltri" => "\u{22ea}".as_bytes(),
    b"nltrie" => "\u{22ec}".as_bytes(),
    b"nmid" => "\u{2224}".as_bytes(),
    b"nopf" => "\u{1d55f}".as_bytes(),
    b"not" => "\u{ac}".as_bytes(),
    b"notin" => "\u{2209}".as_bytes(),
    b"notinE" => "\u{22f9},\u{338}".as_bytes(),
    b"notindot" => "\u{22f5},\u{338}".as_bytes(),
    b"notinva" => "\u{2209}".as_bytes(),
    b"notinvb" => "\u{22f7}".as_bytes(),
    b"notinvc" => "\u{22f6}".as_bytes(),
    b"notni" => "\u{220c}".as_bytes(),
    b"notniva" => "\u{220c}".as_bytes(),
    b"notnivb" => "\u{22fe}".as_bytes(),
    b"notnivc" => "\u{22fd}".as_bytes(),
    b"npar" => "\u{2226}".as_bytes(),
    b"nparallel" => "\u{2226}".as_bytes(),
    b"nparsl" => "\u{2afd},\u{20e5}".as_bytes(),
    b"npart" => "\u{2202},\u{338}".as_bytes(),
    b"npolint" => "\u{2a14}".as_bytes(),
    b"npr" => "\u{2280}".as_bytes(),
    b"nprcue" => "\u{22e0}".as_bytes(),
    b"npre" => "\u{2aaf},\u{338}".as_bytes(),
    b"nprec" => "\u{2280}".as_bytes(),
    b"npreceq" => "\u{2aaf},\u{338}".as_bytes(),
    b"nrArr" => "\u{21cf}".as_bytes(),
    b"nrarr" => "\u{219b}".as_bytes(),
    b"nrarrc" => "\u{2933},\u{338}".as_bytes(),
    b"nrarrw" => "\u{219d},\u{338}".as_bytes(),
    b"nrightarrow" => "\u{219b}".as_bytes(),
    b"nrtri" => "\u{22eb}".as_bytes(),
    b"nrtrie" => "\u{22ed}".as_bytes(),
    b"nsc" => "\u{2281}".as_bytes(),
    b"nsccue" => "\u{22e1}".as_bytes(),
    b"nsce" => "\u{2ab0},\u{338}".as_bytes(),
    b"nscr" => "\u{1d4c3}".as_bytes(),
    b"nshortmid" => "\u{2224}".as_bytes(),
    b"nshortparallel" => "\u{2226}".as_bytes(),
    b"nsim" => "\u{2241}".as_bytes(),
    b"nsime" => "\u{2244}".as_bytes(),
    b"nsimeq" => "\u{2244}".as_bytes(),
    b"nsmid" => "\u{2224}".as_bytes(),
    b"nspar" => "\u{2226}".as_bytes(),
    b"nsqsube" => "\u{22e2}".as_bytes(),
    b"nsqsupe" => "\u{22e3}".as_bytes(),
    b"nsub" => "\u{2284}".as_bytes(),
    b"nsubE" => "\u{2ac5},\u{338}".as_bytes(),
    b"nsube" => "\u{2288}".as_bytes(),
    b"nsubset" => "\u{2282},\u{20d2}".as_bytes(),
    b"nsubseteq" => "\u{2288}".as_bytes(),
    b"nsubseteqq" => "\u{2ac5},\u{338}".as_bytes(),
    b"nsucc" => "\u{2281}".as_bytes(),
    b"nsucceq" => "\u{2ab0},\u{338}".as_bytes(),
    b"nsup" => "\u{2285}".as_bytes(),
    b"nsupE" => "\u{2ac6},\u{338}".as_bytes(),
    b"nsupe" => "\u{2289}".as_bytes(),
    b"nsupset" => "\u{2283},\u{20d2}".as_bytes(),
    b"nsupseteq" => "\u{2289}".as_bytes(),
    b"nsupseteqq" => "\u{2ac6},\u{338}".as_bytes(),
    b"ntgl" => "\u{2279}".as_bytes(),
    b"ntilde" => "\u{f1}".as_bytes(),
    b"ntlg" => "\u{2278}".as_bytes(),
    b"ntriangleleft" => "\u{22ea}".as_bytes(),
    b"ntrianglelefteq" => "\u{22ec}".as_bytes(),
    b"ntriangleright" => "\u{22eb}".as_bytes(),
    b"ntrianglerighteq" => "\u{22ed}".as_bytes(),
    b"nu" => "\u{3bd}".as_bytes(),
    b"num" => "\u{23}".as_bytes(),
    b"numero" => "\u{2116}".as_bytes(),
    b"numsp" => "\u{2007}".as_bytes(),
    b"nvDash" => "\u{22ad}".as_bytes(),
    b"nvHarr" => "\u{2904}".as_bytes(),
    b"nvap" => "\u{224d},\u{20d2}".as_bytes(),
    b"nvdash" => "\u{22ac}".as_bytes(),
    b"nvge" => "\u{2265},\u{20d2}".as_bytes(),
    b"nvgt" => "\u{3e},\u{20d2}".as_bytes(),
    b"nvinfin" => "\u{29de}".as_bytes(),
    b"nvlArr" => "\u{2902}".as_bytes(),
    b"nvle" => "\u{2264},\u{20d2}".as_bytes(),
    b"nvlt" => "\u{3c},\u{20d2}".as_bytes(),
    b"nvltrie" => "\u{22b4},\u{20d2}".as_bytes(),
    b"nvrArr" => "\u{2903}".as_bytes(),
    b"nvrtrie" => "\u{22b5},\u{20d2}".as_bytes(),
    b"nvsim" => "\u{223c},\u{20d2}".as_bytes(),
    b"nwArr" => "\u{21d6}".as_bytes(),
    b"nwarhk" => "\u{2923}".as_bytes(),
    b"nwarr" => "\u{2196}".as_bytes(),
    b"nwarrow" => "\u{2196}".as_bytes(),
    b"nwnear" => "\u{2927}".as_bytes(),
    b"oS" => "\u{24c8}".as_bytes(),
    b"oacute" => "\u{f3}".as_bytes(),
    b"oast" => "\u{229b}".as_bytes(),
    b"ocir" => "\u{229a}".as_bytes(),
    b"ocirc" => "\u{f4}".as_bytes(),
    b"ocy" => "\u{43e}".as_bytes(),
    b"odash" => "\u{229d}".as_bytes(),
    b"odblac" => "\u{151}".as_bytes(),
    b"odiv" => "\u{2a38}".as_bytes(),
    b"odot" => "\u{2299}".as_bytes(),
    b"odsold" => "\u{29bc}".as_bytes(),
    b"oelig" => "\u{153}".as_bytes(),
    b"ofcir" => "\u{29bf}".as_bytes(),
    b"ofr" => "\u{1d52c}".as_bytes(),
    b"ogon" => "\u{2db}".as_bytes(),
    b"ograve" => "\u{f2}".as_bytes(),
    b"ogt" => "\u{29c1}".as_bytes(),
    b"ohbar" => "\u{29b5}".as_bytes(),
    b"ohm" => "\u{3a9}".as_bytes(),
    b"oint" => "\u{222e}".as_bytes(),
    b"olarr" => "\u{21ba}".as_bytes(),
    b"olcir" => "\u{29be}".as_bytes(),
    b"olcross" => "\u{29bb}".as_bytes(),
    b"oline" => "\u{203e}".as_bytes(),
    b"olt" => "\u{29c0}".as_bytes(),
    b"omacr" => "\u{14d}".as_bytes(),
    b"omega" => "\u{3c9}".as_bytes(),
    b"omicron" => "\u{3bf}".as_bytes(),
    b"omid" => "\u{29b6}".as_bytes(),
    b"ominus" => "\u{2296}".as_bytes(),
    b"oopf" => "\u{1d560}".as_bytes(),
    b"opar" => "\u{29b7}".as_bytes(),
    b"operp" => "\u{29b9}".as_bytes(),
    b"oplus" => "\u{2295}".as_bytes(),
    b"or" => "\u{2228}".as_bytes(),
    b"orarr" => "\u{21bb}".as_bytes(),
    b"ord" => "\u{2a5d}".as_bytes(),
    b"order" => "\u{2134}".as_bytes(),
    b"orderof" => "\u{2134}".as_bytes(),
    b"ordf" => "\u{aa}".as_bytes(),
    b"ordm" => "\u{ba}".as_bytes(),
    b"origof" => "\u{22b6}".as_bytes(),
    b"oror" => "\u{2a56}".as_bytes(),
    b"orslope" => "\u{2a57}".as_bytes(),
    b"orv" => "\u{2a5b}".as_bytes(),
    b"oscr" => "\u{2134}".as_bytes(),
    b"oslash" => "\u{f8}".as_bytes(),
    b"osol" => "\u{2298}".as_bytes(),
    b"otilde" => "\u{f5}".as_bytes(),
    b"otimes" => "\u{2297}".as_bytes(),
    b"otimesas" => "\u{2a36}".as_bytes(),
    b"ouml" => "\u{f6}".as_bytes(),
    b"ovbar" => "\u{233d}".as_bytes(),
    b"par" => "\u{2225}".as_bytes(),
    b"para" => "\u{b6}".as_bytes(),
    b"parallel" => "\u{2225}".as_bytes(),
    b"parsim" => "\u{2af3}".as_bytes(),
    b"parsl" => "\u{2afd}".as_bytes(),
    b"part" => "\u{2202}".as_bytes(),
    b"pcy" => "\u{43f}".as_bytes(),
    b"percnt" => "\u{25}".as_bytes(),
    b"period" => "\u{2e}".as_bytes(),
    b"permil" => "\u{2030}".as_bytes(),
    b"perp" => "\u{22a5}".as_bytes(),
    b"pertenk" => "\u{2031}".as_bytes(),
    b"pfr" => "\u{1d52d}".as_bytes(),
    b"phi" => "\u{3c6}".as_bytes(),
    b"phiv" => "\u{3d5}".as_bytes(),
    b"phmmat" => "\u{2133}".as_bytes(),
    b"phone" => "\u{260e}".as_bytes(),
    b"pi" => "\u{3c0}".as_bytes(),
    b"pitchfork" => "\u{22d4}".as_bytes(),
    b"piv" => "\u{3d6}".as_bytes(),
    b"planck" => "\u{210f}".as_bytes(),
    b"planckh" => "\u{210e}".as_bytes(),
    b"plankv" => "\u{210f}".as_bytes(),
    b"plus" => "\u{2b}".as_bytes(),
    b"plusacir" => "\u{2a23}".as_bytes(),
    b"plusb" => "\u{229e}".as_bytes(),
    b"pluscir" => "\u{2a22}".as_bytes(),
    b"plusdo" => "\u{2214}".as_bytes(),
    b"plusdu" => "\u{2a25}".as_bytes(),
    b"pluse" => "\u{2a72}".as_bytes(),
    b"plusmn" => "\u{b1}".as_bytes(),
    b"plussim" => "\u{2a26}".as_bytes(),
    b"plustwo" => "\u{2a27}".as_bytes(),
    b"pm" => "\u{b1}".as_bytes(),
    b"pointint" => "\u{2a15}".as_bytes(),
    b"popf" => "\u{1d561}".as_bytes(),
    b"pound" => "\u{a3}".as_bytes(),
    b"pr" => "\u{227a}".as_bytes(),
    b"prE" => "\u{2ab3}".as_bytes(),
    b"prap" => "\u{2ab7}".as_bytes(),
    b"prcue" => "\u{227c}".as_bytes(),
    b"pre" => "\u{2aaf}".as_bytes(),
    b"prec" => "\u{227a}".as_bytes(),
    b"precapprox" => "\u{2ab7}".as_bytes(),
    b"preccurlyeq" => "\u{227c}".as_bytes(),
    b"preceq" => "\u{2aaf}".as_bytes(),
    b"precnapprox" => "\u{2ab9}".as_bytes(),
    b"precneqq" => "\u{2ab5}".as_bytes(),
    b"precnsim" => "\u{22e8}".as_bytes(),
    b"precsim" => "\u{227e}".as_bytes(),
    b"prime" => "\u{2032}".as_bytes(),
    b"primes" => "\u{2119}".as_bytes(),
    b"prnE" => "\u{2ab5}".as_bytes(),
    b"prnap" => "\u{2ab9}".as_bytes(),
    b"prnsim" => "\u{22e8}".as_bytes(),
    b"prod" => "\u{220f}".as_bytes(),
    b"profalar" => "\u{232e}".as_bytes(),
    b"profline" => "\u{2312}".as_bytes(),
    b"profsurf" => "\u{2313}".as_bytes(),
    b"prop" => "\u{221d}".as_bytes(),
    b"propto" => "\u{221d}".as_bytes(),
    b"prsim" => "\u{227e}".as_bytes(),
    b"prurel" => "\u{22b0}".as_bytes(),
    b"pscr" => "\u{1d4c5}".as_bytes(),
    b"psi" => "\u{3c8}".as_bytes(),
    b"puncsp" => "\u{2008}".as_bytes(),
    b"qfr" => "\u{1d52e}".as_bytes(),
    b"qint" => "\u{2a0c}".as_bytes(),
    b"qopf" => "\u{1d562}".as_bytes(),
    b"qprime" => "\u{2057}".as_bytes(),
    b"qscr" => "\u{1d4c6}".as_bytes(),
    b"quaternions" => "\u{210d}".as_bytes(),
    b"quatint" => "\u{2a16}".as_bytes(),
    b"quest" => "\u{3f}".as_bytes(),
    b"questeq" => "\u{225f}".as_bytes(),
    b"quot" => "\u{22}".as_bytes(),
    b"rAarr" => "\u{21db}".as_bytes(),
    b"rArr" => "\u{21d2}".as_bytes(),
    b"rAtail" => "\u{291c}".as_bytes(),
    b"rBarr" => "\u{290f}".as_bytes(),
    b"rHar" => "\u{2964}".as_bytes(),
    b"race" => "\u{223d},\u{331}".as_bytes(),
    b"racute" => "\u{155}".as_bytes(),
    b"radic" => "\u{221a}".as_bytes(),
    b"raemptyv" => "\u{29b3}".as_bytes(),
    b"rang" => "\u{27e9}".as_bytes(),
    b"rangd" => "\u{2992}".as_bytes(),
    b"range" => "\u{29a5}".as_bytes(),
    b"rangle" => "\u{27e9}".as_bytes(),
    b"raquo" => "\u{bb}".as_bytes(),
    b"rarr" => "\u{2192}".as_bytes(),
    b"rarrap" => "\u{2975}".as_bytes(),
    b"rarrb" => "\u{21e5}".as_bytes(),
    b"rarrbfs" => "\u{2920}".as_bytes(),
    b"rarrc" => "\u{2933}".as_bytes(),
    b"rarrfs" => "\u{291e}".as_bytes(),
    b"rarrhk" => "\u{21aa}".as_bytes(),
    b"rarrlp" => "\u{21ac}".as_bytes(),
    b"rarrpl" => "\u{2945}".as_bytes(),
    b"rarrsim" => "\u{2974}".as_bytes(),
    b"rarrtl" => "\u{21a3}".as_bytes(),
    b"rarrw" => "\u{219d}".as_bytes(),
    b"ratail" => "\u{291a}".as_bytes(),
    b"ratio" => "\u{2236}".as_bytes(),
    b"rationals" => "\u{211a}".as_bytes(),
    b"rbarr" => "\u{290d}".as_bytes(),
    b"rbbrk" => "\u{2773}".as_bytes(),
    b"rbrace" => "\u{7d}".as_bytes(),
    b"rbrack" => "\u{5d}".as_bytes(),
    b"rbrke" => "\u{298c}".as_bytes(),
    b"rbrksld" => "\u{298e}".as_bytes(),
    b"rbrkslu" => "\u{2990}".as_bytes(),
    b"rcaron" => "\u{159}".as_bytes(),
    b"rcedil" => "\u{157}".as_bytes(),
    b"rceil" => "\u{2309}".as_bytes(),
    b"rcub" => "\u{7d}".as_bytes(),
    b"rcy" => "\u{440}".as_bytes(),
    b"rdca" => "\u{2937}".as_bytes(),
    b"rdldhar" => "\u{2969}".as_bytes(),
    b"rdquo" => "\u{201d}".as_bytes(),
    b"rdquor" => "\u{201d}".as_bytes(),
    b"rdsh" => "\u{21b3}".as_bytes(),
    b"real" => "\u{211c}".as_bytes(),
    b"realine" => "\u{211b}".as_bytes(),
    b"realpart" => "\u{211c}".as_bytes(),
    b"reals" => "\u{211d}".as_bytes(),
    b"rect" => "\u{25ad}".as_bytes(),
    b"reg" => "\u{ae}".as_bytes(),
    b"rfisht" => "\u{297d}".as_bytes(),
    b"rfloor" => "\u{230b}".as_bytes(),
    b"rfr" => "\u{1d52f}".as_bytes(),
    b"rhard" => "\u{21c1}".as_bytes(),
    b"rharu" => "\u{21c0}".as_bytes(),
    b"rharul" => "\u{296c}".as_bytes(),
    b"rho" => "\u{3c1}".as_bytes(),
    b"rhov" => "\u{3f1}".as_bytes(),
    b"rightarrow" => "\u{2192}".as_bytes(),
    b"rightarrowtail" => "\u{21a3}".as_bytes(),
    b"rightharpoondown" => "\u{21c1}".as_bytes(),
    b"rightharpoonup" => "\u{21c0}".as_bytes(),
    b"rightleftarrows" => "\u{21c4}".as_bytes(),
    b"rightleftharpoons" => "\u{21cc}".as_bytes(),
    b"rightrightarrows" => "\u{21c9}".as_bytes(),
    b"rightsquigarrow" => "\u{219d}".as_bytes(),
    b"rightthreetimes" => "\u{22cc}".as_bytes(),
    b"ring" => "\u{2da}".as_bytes(),
    b"risingdotseq" => "\u{2253}".as_bytes(),
    b"rlarr" => "\u{21c4}".as_bytes(),
    b"rlhar" => "\u{21cc}".as_bytes(),
    b"rlm" => "\u{200f}".as_bytes(),
    b"rmoust" => "\u{23b1}".as_bytes(),
    b"rmoustache" => "\u{23b1}".as_bytes(),
    b"rnmid" => "\u{2aee}".as_bytes(),
    b"roang" => "\u{27ed}".as_bytes(),
    b"roarr" => "\u{21fe}".as_bytes(),
    b"robrk" => "\u{27e7}".as_bytes(),
    b"ropar" => "\u{2986}".as_bytes(),
    b"ropf" => "\u{1d563}".as_bytes(),
    b"roplus" => "\u{2a2e}".as_bytes(),
    b"rotimes" => "\u{2a35}".as_bytes(),
    b"rpar" => "\u{29}".as_bytes(),
    b"rpargt" => "\u{2994}".as_bytes(),
    b"rppolint" => "\u{2a12}".as_bytes(),
    b"rrarr" => "\u{21c9}".as_bytes(),
    b"rsaquo" => "\u{203a}".as_bytes(),
    b"rscr" => "\u{1d4c7}".as_bytes(),
    b"rsh" => "\u{21b1}".as_bytes(),
    b"rsqb" => "\u{5d}".as_bytes(),
    b"rsquo" => "\u{2019}".as_bytes(),
    b"rsquor" => "\u{2019}".as_bytes(),
    b"rthree" => "\u{22cc}".as_bytes(),
    b"rtimes" => "\u{22ca}".as_bytes(),
    b"rtri" => "\u{25b9}".as_bytes(),
    b"rtrie" => "\u{22b5}".as_bytes(),
    b"rtrif" => "\u{25b8}".as_bytes(),
    b"rtriltri" => "\u{29ce}".as_bytes(),
    b"ruluhar" => "\u{2968}".as_bytes(),
    b"rx" => "\u{211e}".as_bytes(),
    b"sacute" => "\u{15b}".as_bytes(),
    b"sbquo" => "\u{201a}".as_bytes(),
    b"sc" => "\u{227b}".as_bytes(),
    b"scE" => "\u{2ab4}".as_bytes(),
    b"scap" => "\u{2ab8}".as_bytes(),
    b"scaron" => "\u{161}".as_bytes(),
    b"sccue" => "\u{227d}".as_bytes(),
    b"sce" => "\u{2ab0}".as_bytes(),
    b"scedil" => "\u{15f}".as_bytes(),
    b"scirc" => "\u{15d}".as_bytes(),
    b"scnE" => "\u{2ab6}".as_bytes(),
    b"scnap" => "\u{2aba}".as_bytes(),
    b"scnsim" => "\u{22e9}".as_bytes(),
    b"scpolint" => "\u{2a13}".as_bytes(),
    b"scsim" => "\u{227f}".as_bytes(),
    b"scy" => "\u{441}".as_bytes(),
    b"sdot" => "\u{22c5}".as_bytes(),
    b"sdotb" => "\u{22a1}".as_bytes(),
    b"sdote" => "\u{2a66}".as_bytes(),
    b"seArr" => "\u{21d8}".as_bytes(),
    b"searhk" => "\u{2925}".as_bytes(),
    b"searr" => "\u{2198}".as_bytes(),
    b"searrow" => "\u{2198}".as_bytes(),
    b"sect" => "\u{a7}".as_bytes(),
    b"semi" => "\u{3b}".as_bytes(),
    b"seswar" => "\u{2929}".as_bytes(),
    b"setminus" => "\u{2216}".as_bytes(),
    b"setmn" => "\u{2216}".as_bytes(),
    b"sext" => "\u{2736}".as_bytes(),
    b"sfr" => "\u{1d530}".as_bytes(),
    b"sfrown" => "\u{2322}".as_bytes(),
    b"sharp" => "\u{266f}".as_bytes(),
    b"shchcy" => "\u{449}".as_bytes(),
    b"shcy" => "\u{448}".as_bytes(),
    b"shortmid" => "\u{2223}".as_bytes(),
    b"shortparallel" => "\u{2225}".as_bytes(),
    b"shy" => "\u{ad}".as_bytes(),
    b"sigma" => "\u{3c3}".as_bytes(),
    b"sigmaf" => "\u{3c2}".as_bytes(),
    b"sigmav" => "\u{3c2}".as_bytes(),
    b"sim" => "\u{223c}".as_bytes(),
    b"simdot" => "\u{2a6a}".as_bytes(),
    b"sime" => "\u{2243}".as_bytes(),
    b"simeq" => "\u{2243}".as_bytes(),
    b"simg" => "\u{2a9e}".as_bytes(),
    b"simgE" => "\u{2aa0}".as_bytes(),
    b"siml" => "\u{2a9d}".as_bytes(),
    b"simlE" => "\u{2a9f}".as_bytes(),
    b"simne" => "\u{2246}".as_bytes(),
    b"simplus" => "\u{2a24}".as_bytes(),
    b"simrarr" => "\u{2972}".as_bytes(),
    b"slarr" => "\u{2190}".as_bytes(),
    b"smallsetminus" => "\u{2216}".as_bytes(),
    b"smashp" => "\u{2a33}".as_bytes(),
    b"smeparsl" => "\u{29e4}".as_bytes(),
    b"smid" => "\u{2223}".as_bytes(),
    b"smile" => "\u{2323}".as_bytes(),
    b"smt" => "\u{2aaa}".as_bytes(),
    b"smte" => "\u{2aac}".as_bytes(),
    b"smtes" => "\u{2aac},\u{fe00}".as_bytes(),
    b"softcy" => "\u{44c}".as_bytes(),
    b"sol" => "\u{2f}".as_bytes(),
    b"solb" => "\u{29c4}".as_bytes(),
    b"solbar" => "\u{233f}".as_bytes(),
    b"sopf" => "\u{1d564}".as_bytes(),
    b"spades" => "\u{2660}".as_bytes(),
    b"spadesuit" => "\u{2660}".as_bytes(),
    b"spar" => "\u{2225}".as_bytes(),
    b"sqcap" => "\u{2293}".as_bytes(),
    b"sqcaps" => "\u{2293},\u{fe00}".as_bytes(),
    b"sqcup" => "\u{2294}".as_bytes(),
    b"sqcups" => "\u{2294},\u{fe00}".as_bytes(),
    b"sqsub" => "\u{228f}".as_bytes(),
    b"sqsube" => "\u{2291}".as_bytes(),
    b"sqsubset" => "\u{228f}".as_bytes(),
    b"sqsubseteq" => "\u{2291}".as_bytes(),
    b"sqsup" => "\u{2290}".as_bytes(),
    b"sqsupe" => "\u{2292}".as_bytes(),
    b"sqsupset" => "\u{2290}".as_bytes(),
    b"sqsupseteq" => "\u{2292}".as_bytes(),
    b"squ" => "\u{25a1}".as_bytes(),
    b"square" => "\u{25a1}".as_bytes(),
    b"squarf" => "\u{25aa}".as_bytes(),
    b"squf" => "\u{25aa}".as_bytes(),
    b"srarr" => "\u{2192}".as_bytes(),
    b"sscr" => "\u{1d4c8}".as_bytes(),
    b"ssetmn" => "\u{2216}".as_bytes(),
    b"ssmile" => "\u{2323}".as_bytes(),
    b"sstarf" => "\u{22c6}".as_bytes(),
    b"star" => "\u{2606}".as_bytes(),
    b"starf" => "\u{2605}".as_bytes(),
    b"straightepsilon" => "\u{3f5}".as_bytes(),
    b"straightphi" => "\u{3d5}".as_bytes(),
    b"strns" => "\u{af}".as_bytes(),
    b"sub" => "\u{2282}".as_bytes(),
    b"subE" => "\u{2ac5}".as_bytes(),
    b"subdot" => "\u{2abd}".as_bytes(),
    b"sube" => "\u{2286}".as_bytes(),
    b"subedot" => "\u{2ac3}".as_bytes(),
    b"submult" => "\u{2ac1}".as_bytes(),
    b"subnE" => "\u{2acb}".as_bytes(),
    b"subne" => "\u{228a}".as_bytes(),
    b"subplus" => "\u{2abf}".as_bytes(),
    b"subrarr" => "\u{2979}".as_bytes(),
    b"subset" => "\u{2282}".as_bytes(),
    b"subseteq" => "\u{2286}".as_bytes(),
    b"subseteqq" => "\u{2ac5}".as_bytes(),
    b"subsetneq" => "\u{228a}".as_bytes(),
    b"subsetneqq" => "\u{2acb}".as_bytes(),
    b"subsim" => "\u{2ac7}".as_bytes(),
    b"subsub" => "\u{2ad5}".as_bytes(),
    b"subsup" => "\u{2ad3}".as_bytes(),
    b"succ" => "\u{227b}".as_bytes(),
    b"succapprox" => "\u{2ab8}".as_bytes(),
    b"succcurlyeq" => "\u{227d}".as_bytes(),
    b"succeq" => "\u{2ab0}".as_bytes(),
    b"succnapprox" => "\u{2aba}".as_bytes(),
    b"succneqq" => "\u{2ab6}".as_bytes(),
    b"succnsim" => "\u{22e9}".as_bytes(),
    b"succsim" => "\u{227f}".as_bytes(),
    b"sum" => "\u{2211}".as_bytes(),
    b"sung" => "\u{266a}".as_bytes(),
    b"sup1" => "\u{b9}".as_bytes(),
    b"sup2" => "\u{b2}".as_bytes(),
    b"sup3" => "\u{b3}".as_bytes(),
    b"sup" => "\u{2283}".as_bytes(),
    b"supE" => "\u{2ac6}".as_bytes(),
    b"supdot" => "\u{2abe}".as_bytes(),
    b"supdsub" => "\u{2ad8}".as_bytes(),
    b"supe" => "\u{2287}".as_bytes(),
    b"supedot" => "\u{2ac4}".as_bytes(),
    b"suphsol" => "\u{27c9}".as_bytes(),
    b"suphsub" => "\u{2ad7}".as_bytes(),
    b"suplarr" => "\u{297b}".as_bytes(),
    b"supmult" => "\u{2ac2}".as_bytes(),
    b"supnE" => "\u{2acc}".as_bytes(),
    b"supne" => "\u{228b}".as_bytes(),
    b"supplus" => "\u{2ac0}".as_bytes(),
    b"supset" => "\u{2283}".as_bytes(),
    b"supseteq" => "\u{2287}".as_bytes(),
    b"supseteqq" => "\u{2ac6}".as_bytes(),
    b"supsetneq" => "\u{228b}".as_bytes(),
    b"supsetneqq" => "\u{2acc}".as_bytes(),
    b"supsim" => "\u{2ac8}".as_bytes(),
    b"supsub" => "\u{2ad4}".as_bytes(),
    b"supsup" => "\u{2ad6}".as_bytes(),
    b"swArr" => "\u{21d9}".as_bytes(),
    b"swarhk" => "\u{2926}".as_bytes(),
    b"swarr" => "\u{2199}".as_bytes(),
    b"swarrow" => "\u{2199}".as_bytes(),
    b"swnwar" => "\u{292a}".as_bytes(),
    b"szlig" => "\u{df}".as_bytes(),
    b"target" => "\u{2316}".as_bytes(),
    b"tau" => "\u{3c4}".as_bytes(),
    b"tbrk" => "\u{23b4}".as_bytes(),
    b"tcaron" => "\u{165}".as_bytes(),
    b"tcedil" => "\u{163}".as_bytes(),
    b"tcy" => "\u{442}".as_bytes(),
    b"tdot" => "\u{20db}".as_bytes(),
    b"telrec" => "\u{2315}".as_bytes(),
    b"tfr" => "\u{1d531}".as_bytes(),
    b"there4" => "\u{2234}".as_bytes(),
    b"therefore" => "\u{2234}".as_bytes(),
    b"theta" => "\u{3b8}".as_bytes(),
    b"thetasym" => "\u{3d1}".as_bytes(),
    b"thetav" => "\u{3d1}".as_bytes(),
    b"thickapprox" => "\u{2248}".as_bytes(),
    b"thicksim" => "\u{223c}".as_bytes(),
    b"thinsp" => "\u{2009}".as_bytes(),
    b"thkap" => "\u{2248}".as_bytes(),
    b"thksim" => "\u{223c}".as_bytes(),
    b"thorn" => "\u{fe}".as_bytes(),
    b"tilde" => "\u{2dc}".as_bytes(),
    b"times" => "\u{d7}".as_bytes(),
    b"timesb" => "\u{22a0}".as_bytes(),
    b"timesbar" => "\u{2a31}".as_bytes(),
    b"timesd" => "\u{2a30}".as_bytes(),
    b"tint" => "\u{222d}".as_bytes(),
    b"toea" => "\u{2928}".as_bytes(),
    b"top" => "\u{22a4}".as_bytes(),
    b"topbot" => "\u{2336}".as_bytes(),
    b"topcir" => "\u{2af1}".as_bytes(),
    b"topf" => "\u{1d565}".as_bytes(),
    b"topfork" => "\u{2ada}".as_bytes(),
    b"tosa" => "\u{2929}".as_bytes(),
    b"tprime" => "\u{2034}".as_bytes(),
    b"trade" => "\u{2122}".as_bytes(),
    b"triangle" => "\u{25b5}".as_bytes(),
    b"triangledown" => "\u{25bf}".as_bytes(),
    b"triangleleft" => "\u{25c3}".as_bytes(),
    b"trianglelefteq" => "\u{22b4}".as_bytes(),
    b"triangleq" => "\u{225c}".as_bytes(),
    b"triangleright" => "\u{25b9}".as_bytes(),
    b"trianglerighteq" => "\u{22b5}".as_bytes(),
    b"tridot" => "\u{25ec}".as_bytes(),
    b"trie" => "\u{225c}".as_bytes(),
    b"triminus" => "\u{2a3a}".as_bytes(),
    b"triplus" => "\u{2a39}".as_bytes(),
    b"trisb" => "\u{29cd}".as_bytes(),
    b"tritime" => "\u{2a3b}".as_bytes(),
    b"trpezium" => "\u{23e2}".as_bytes(),
    b"tscr" => "\u{1d4c9}".as_bytes(),
    b"tscy" => "\u{446}".as_bytes(),
    b"tshcy" => "\u{45b}".as_bytes(),
    b"tstrok" => "\u{167}".as_bytes(),
    b"twixt" => "\u{226c}".as_bytes(),
    b"twoheadleftarrow" => "\u{219e}".as_bytes(),
    b"twoheadrightarrow" => "\u{21a0}".as_bytes(),
    b"uArr" => "\u{21d1}".as_bytes(),
    b"uHar" => "\u{2963}".as_bytes(),
    b"uacute" => "\u{fa}".as_bytes(),
    b"uarr" => "\u{2191}".as_bytes(),
    b"ubrcy" => "\u{45e}".as_bytes(),
    b"ubreve" => "\u{16d}".as_bytes(),
    b"ucirc" => "\u{fb}".as_bytes(),
    b"ucy" => "\u{443}".as_bytes(),
    b"udarr" => "\u{21c5}".as_bytes(),
    b"udblac" => "\u{171}".as_bytes(),
    b"udhar" => "\u{296e}".as_bytes(),
    b"ufisht" => "\u{297e}".as_bytes(),
    b"ufr" => "\u{1d532}".as_bytes(),
    b"ugrave" => "\u{f9}".as_bytes(),
    b"uharl" => "\u{21bf}".as_bytes(),
    b"uharr" => "\u{21be}".as_bytes(),
    b"uhblk" => "\u{2580}".as_bytes(),
    b"ulcorn" => "\u{231c}".as_bytes(),
    b"ulcorner" => "\u{231c}".as_bytes(),
    b"ulcrop" => "\u{230f}".as_bytes(),
    b"ultri" => "\u{25f8}".as_bytes(),
    b"umacr" => "\u{16b}".as_bytes(),
    b"uml" => "\u{a8}".as_bytes(),
    b"uogon" => "\u{173}".as_bytes(),
    b"uopf" => "\u{1d566}".as_bytes(),
    b"uparrow" => "\u{2191}".as_bytes(),
    b"updownarrow" => "\u{2195}".as_bytes(),
    b"upharpoonleft" => "\u{21bf}".as_bytes(),
    b"upharpoonright" => "\u{21be}".as_bytes(),
    b"uplus" => "\u{228e}".as_bytes(),
    b"upsi" => "\u{3c5}".as_bytes(),
    b"upsih" => "\u{3d2}".as_bytes(),
    b"upsilon" => "\u{3c5}".as_bytes(),
    b"upuparrows" => "\u{21c8}".as_bytes(),
    b"urcorn" => "\u{231d}".as_bytes(),
    b"urcorner" => "\u{231d}".as_bytes(),
    b"urcrop" => "\u{230e}".as_bytes(),
    b"uring" => "\u{16f}".as_bytes(),
    b"urtri" => "\u{25f9}".as_bytes(),
    b"uscr" => "\u{1d4ca}".as_bytes(),
    b"utdot" => "\u{22f0}".as_bytes(),
    b"utilde" => "\u{169}".as_bytes(),
    b"utri" => "\u{25b5}".as_bytes(),
    b"utrif" => "\u{25b4}".as_bytes(),
    b"uuarr" => "\u{21c8}".as_bytes(),
    b"uuml" => "\u{fc}".as_bytes(),
    b"uwangle" => "\u{29a7}".as_bytes(),
    b"vArr" => "\u{21d5}".as_bytes(),
    b"vBar" => "\u{2ae8}".as_bytes(),
    b"vBarv" => "\u{2ae9}".as_bytes(),
    b"vDash" => "\u{22a8}".as_bytes(),
    b"vangrt" => "\u{299c}".as_bytes(),
    b"varepsilon" => "\u{3f5}".as_bytes(),
    b"varkappa" => "\u{3f0}".as_bytes(),
    b"varnothing" => "\u{2205}".as_bytes(),
    b"varphi" => "\u{3d5}".as_bytes(),
    b"varpi" => "\u{3d6}".as_bytes(),
    b"varpropto" => "\u{221d}".as_bytes(),
    b"varr" => "\u{2195}".as_bytes(),
    b"varrho" => "\u{3f1}".as_bytes(),
    b"varsigma" => "\u{3c2}".as_bytes(),
    b"varsubsetneq" => "\u{228a},\u{fe00}".as_bytes(),
    b"varsubsetneqq" => "\u{2acb},\u{fe00}".as_bytes(),
    b"varsupsetneq" => "\u{228b},\u{fe00}".as_bytes(),
    b"varsupsetneqq" => "\u{2acc},\u{fe00}".as_bytes(),
    b"vartheta" => "\u{3d1}".as_bytes(),
    b"vartriangleleft" => "\u{22b2}".as_bytes(),
    b"vartriangleright" => "\u{22b3}".as_bytes(),
    b"vcy" => "\u{432}".as_bytes(),
    b"vdash" => "\u{22a2}".as_bytes(),
    b"vee" => "\u{2228}".as_bytes(),
    b"veebar" => "\u{22bb}".as_bytes(),
    b"veeeq" => "\u{225a}".as_bytes(),
    b"vellip" => "\u{22ee}".as_bytes(),
    b"verbar" => "\u{7c}".as_bytes(),
    b"vert" => "\u{7c}".as_bytes(),
    b"vfr" => "\u{1d533}".as_bytes(),
    b"vltri" => "\u{22b2}".as_bytes(),
    b"vnsub" => "\u{2282},\u{20d2}".as_bytes(),
    b"vnsup" => "\u{2283},\u{20d2}".as_bytes(),
    b"vopf" => "\u{1d567}".as_bytes(),
    b"vprop" => "\u{221d}".as_bytes(),
    b"vrtri" => "\u{22b3}".as_bytes(),
    b"vscr" => "\u{1d4cb}".as_bytes(),
    b"vsubnE" => "\u{2acb},\u{fe00}".as_bytes(),
    b"vsubne" => "\u{228a},\u{fe00}".as_bytes(),
    b"vsupnE" => "\u{2acc},\u{fe00}".as_bytes(),
    b"vsupne" => "\u{228b},\u{fe00}".as_bytes(),
    b"vzigzag" => "\u{299a}".as_bytes(),
    b"wcirc" => "\u{175}".as_bytes(),
    b"wedbar" => "\u{2a5f}".as_bytes(),
    b"wedge" => "\u{2227}".as_bytes(),
    b"wedgeq" => "\u{2259}".as_bytes(),
    b"weierp" => "\u{2118}".as_bytes(),
    b"wfr" => "\u{1d534}".as_bytes(),
    b"wopf" => "\u{1d568}".as_bytes(),
    b"wp" => "\u{2118}".as_bytes(),
    b"wr" => "\u{2240}".as_bytes(),
    b"wreath" => "\u{2240}".as_bytes(),
    b"wscr" => "\u{1d4cc}".as_bytes(),
    b"xcap" => "\u{22c2}".as_bytes(),
    b"xcirc" => "\u{25ef}".as_bytes(),
    b"xcup" => "\u{22c3}".as_bytes(),
    b"xdtri" => "\u{25bd}".as_bytes(),
    b"xfr" => "\u{1d535}".as_bytes(),
    b"xhArr" => "\u{27fa}".as_bytes(),
    b"xharr" => "\u{27f7}".as_bytes(),
    b"xi" => "\u{3be}".as_bytes(),
    b"xlArr" => "\u{27f8}".as_bytes(),
    b"xlarr" => "\u{27f5}".as_bytes(),
    b"xmap" => "\u{27fc}".as_bytes(),
    b"xnis" => "\u{22fb}".as_bytes(),
    b"xodot" => "\u{2a00}".as_bytes(),
    b"xopf" => "\u{1d569}".as_bytes(),
    b"xoplus" => "\u{2a01}".as_bytes(),
    b"xotime" => "\u{2a02}".as_bytes(),
    b"xrArr" => "\u{27f9}".as_bytes(),
    b"xrarr" => "\u{27f6}".as_bytes(),
    b"xscr" => "\u{1d4cd}".as_bytes(),
    b"xsqcup" => "\u{2a06}".as_bytes(),
    b"xuplus" => "\u{2a04}".as_bytes(),
    b"xutri" => "\u{25b3}".as_bytes(),
    b"xvee" => "\u{22c1}".as_bytes(),
    b"xwedge" => "\u{22c0}".as_bytes(),
    b"yacute" => "\u{fd}".as_bytes(),
    b"yacy" => "\u{44f}".as_bytes(),
    b"ycirc" => "\u{177}".as_bytes(),
    b"ycy" => "\u{44b}".as_bytes(),
    b"yen" => "\u{a5}".as_bytes(),
    b"yfr" => "\u{1d536}".as_bytes(),
    b"yicy" => "\u{457}".as_bytes(),
    b"yopf" => "\u{1d56a}".as_bytes(),
    b"yscr" => "\u{1d4ce}".as_bytes(),
    b"yucy" => "\u{44e}".as_bytes(),
    b"yuml" => "\u{ff}".as_bytes(),
    b"zacute" => "\u{17a}".as_bytes(),
    b"zcaron" => "\u{17e}".as_bytes(),
    b"zcy" => "\u{437}".as_bytes(),
    b"zdot" => "\u{17c}".as_bytes(),
    b"zeetrf" => "\u{2128}".as_bytes(),
    b"zeta" => "\u{3b6}".as_bytes(),
    b"zfr" => "\u{1d537}".as_bytes(),
    b"zhcy" => "\u{436}".as_bytes(),
    b"zigrarr" => "\u{21dd}".as_bytes(),
    b"zopf" => "\u{1d56b}".as_bytes(),
    b"zscr" => "\u{1d4cf}".as_bytes(),
    b"zwj" => "\u{200d}".as_bytes(),
    b"zwnj" => "\u{200c}".as_bytes(),
};

pub fn is_valid_entity_reference_name_char(c: u8) -> bool {
    c >= b'0' && c <= b'9' || c >= b'A' && c <= b'Z' || c >= b'a' && c <= b'z'
}
